@@ -4,7 +4,7 @@ from ase.atom import Atom
 from ase.atoms import Atoms
 from ase.units import *
 from ase.io import read, write
-from ase.io.trajectory import PickleTrajectory
+from ase.io.trajectory import Trajectory
 from ase.dft import STM, monkhorst_pack, DOS
 from ase.optimize.mdmin import MDMin
 from ase.optimize.lbfgs import HessLBFGS
@@ -18,7 +18,6 @@ from ase.constraints import *
 from ase.calculators.lj import LennardJones
 from ase.calculators.emt import EMT
 from ase.calculators.siesta import Siesta
-from ase.calculators.dacapo import Dacapo
 from ase.calculators.vasp import Vasp
 from ase.calculators.aims import Aims, AimsCube
 from ase.calculators.turbomole import Turbomole
@@ -29,7 +28,6 @@ from ase.dimer import DimerControl, DimerAtoms, DimerTranslate, \
 from ase.visualize import view
 from ase.data import chemical_symbols, atomic_numbers, atomic_names, \
      atomic_masses, covalent_radii, reference_states
-from ase.data.molecules import molecule
 from ase.structure import *
 #from ase.lattice import bulk
 
