@@ -28,6 +28,7 @@ keys_with_units = {
     'zmmaxdispllength': 'Ang',
     'zmmaxdisplangle': 'rad',
     'ecut': 'eV',
+    'pawecutdg': 'eV',
     'dmenergytolerance': 'eV',
     'electronictemperature': 'eV',
     'oneta': 'eV',
@@ -83,34 +84,6 @@ class Abinit(FileIOCalculator):
         label: str
             Prefix to use for filenames (label.in, label.txt, ...).
             Default is 'abinit'.
-        xc: str
-            Exchange-correlation functional.  Must be one of LDA, PBE,
-            revPBE, RPBE.
-        kpts: list of three int
-            Monkhost-Pack sampling.
-        nbands: int
-            Number of bands.
-            For the values of occopt not equal to 0 or 2, nbands can be omitted.
-        nstep: int
-            Number of self-consistent field STEPS.
-        width: float
-            Fermi-distribution width in eV.
-            Default is 0.04 Hartree.
-        ecut: float
-            Planewave cutoff energy in eV.
-            No default.
-        charge: float
-            Total charge of the system.
-            Default is 0.
-        npulayit: int
-            Number of old densities to use for Pulay mixing.
-        diemix: float
-            Mixing parameter between zero and one for density mixing.
-        diemac: float
-            Model DIElectric MACroscopic constant.
-            The value of diemac should usually be bigger than 1.0d0,
-            on physical grounds. If you let diemac to its default value,
-            you might even never obtain the self-consistent convergence!
 
         Examples
         ========
@@ -147,15 +120,16 @@ class Abinit(FileIOCalculator):
 
         FileIOCalculator.write_input(self, atoms, properties, system_changes)
 
-        if 'numbers' in system_changes or 'magmoms' in system_changes:
+        if ('numbers' in system_changes or
+            'initial_magmoms' in system_changes):
             self.initialize(atoms)
 
         fh = open(self.label + '.files', 'w')
 
-        fh.write('%s\n' % (self.prefix + '.in')) # input
-        fh.write('%s\n' % (self.prefix + '.txt')) # output
-        fh.write('%s\n' % (self.prefix + 'i')) # input
-        fh.write('%s\n' % (self.prefix + 'o')) # output
+        fh.write('%s\n' % (self.prefix + '.in'))  # input
+        fh.write('%s\n' % (self.prefix + '.txt'))  # output
+        fh.write('%s\n' % (self.prefix + 'i'))  # input
+        fh.write('%s\n' % (self.prefix + 'o'))  # output
         
         # XXX:
         # scratch files
@@ -239,7 +213,7 @@ class Abinit(FileIOCalculator):
 
         fh.write('#Definition of the unit cell\n')
         fh.write('acell\n')
-        fh.write('%.14f %.14f %.14f Angstrom\n' %  (1.0, 1.0, 1.0))
+        fh.write('%.14f %.14f %.14f Angstrom\n' % (1.0, 1.0, 1.0))
         fh.write('rprim\n')
         for v in atoms.cell:
             fh.write('%.14f %.14f %.14f\n' %  tuple(v))
@@ -259,7 +233,7 @@ class Abinit(FileIOCalculator):
         for Z in atoms.numbers:
             for n, Zs in enumerate(self.species):
                 if Z == Zs:
-                    self.types.append(n+1)
+                    self.types.append(n + 1)
         n_entries_int = 20  # integer entries per line
         for n, type in enumerate(self.types):
             fh.write(' %d' % (type))
@@ -291,10 +265,10 @@ class Abinit(FileIOCalculator):
         if not os.path.isfile(filename):
             raise ReadError
 
-        self.state = read_abinit(self.label + '.in')
+        self.atoms = read_abinit(self.label + '.in')
         self.parameters = Parameters.read(self.label + '.ase')
 
-        self.initialize(self.state)
+        self.initialize(self.atoms)
         self.read_results()
 
     def read_results(self):
@@ -330,24 +304,27 @@ class Abinit(FileIOCalculator):
 
         # Energy [Hartree]:
         # Warning: Etotal could mean both electronic energy and free energy!
-        for line in iter(text.split('\n')):
-            if line.rfind('>>>>> internal e=') > -1:
-                etotal = float(line.split('=')[-1])*Hartree
-                for line1 in iter(text.split('\n')):
-                    if line1.rfind('>>>>>>>>> etotal=') > -1:
-                        efree = float(line1.split('=')[-1])*Hartree
-                        break
-                else:
-                    raise RuntimeError
-                break
+        etotal = None
+        efree = None
+        if 'PAW method is used'.lower() in text:  # read DC energy according to M. Torrent
+            for line in iter(text.split('\n')):
+                if line.rfind('>>>>> internal e=') > -1:
+                    etotal = float(line.split('=')[-1])*Hartree  # second occurence!
+            for line in iter(text.split('\n')):
+                if line.rfind('>>>> etotal (dc)=') > -1:
+                    efree = float(line.split('=')[-1])*Hartree
         else:
-            for line2 in iter(text.split('\n')):
-                if line2.rfind('>>>>>>>>> etotal=') > -1:
-                    etotal = float(line2.split('=')[-1])*Hartree
-                    efree = etotal
+            for line in iter(text.split('\n')):
+                if line.rfind('>>>>> internal e=') > -1:
+                    etotal = float(line.split('=')[-1])*Hartree  # first occurence!
                     break
-            else:
-                raise RuntimeError
+            for line in iter(text.split('\n')):
+                if line.rfind('>>>>>>>>> etotal=') > -1:
+                    efree = float(line.split('=')[-1])*Hartree
+        if efree is None:
+            raise RuntimeError('Total energy not found')
+        if etotal is None:
+            etotal = efree
 
         # Energy extrapolated to zero Kelvin:
         self.results['energy'] = (etotal + efree) / 2
@@ -365,6 +342,7 @@ class Abinit(FileIOCalculator):
         else:
             raise RuntimeError
         #
+        self.width = self.read_electronic_temperature()
         self.nband = self.read_number_of_bands()
         self.niter = self.read_number_of_iterations()
         self.nelect = self.read_number_of_electrons()
@@ -443,7 +421,7 @@ class Abinit(FileIOCalculator):
                                       for name in filenames])
                         name = hghtemplate % (number, symbol.lower(), str(Z))
                     elif pps == 'hgh.k':
-                        selector = min  # Semicore - highest electron count
+                        selector = max  # Semicore - highest electron count
                         Z = selector(
                             [int(os.path.split(name)[1].split('-')[1][:-6][1:])
                              for name in filenames])
@@ -477,7 +455,15 @@ class Abinit(FileIOCalculator):
         return niter
 
     def get_electronic_temperature(self):
-        return self.parameters.width
+        return self.width * Hartree
+
+    def read_electronic_temperature(self):
+        width = None
+        # only in log file!
+        for line in open(self.label + '.log'):  # find last one
+            if line.find('tsmear') != -1:
+                width = float(line.split()[1].strip())
+        return width
 
     def get_number_of_electrons(self):
         return self.nelect
@@ -563,13 +549,14 @@ class Abinit(FileIOCalculator):
         # kpt#   2, nband=  3, wtk=  0.04688, kpt=  0.1875  0.0625  0.0625 (reduced coord)
         # ...
         #
-        assert mode in ['eigenvalues' , 'occupations', 'ibz_k_points', 'k_point_weights'], 'mode not in [\'eigenvalues\' , \'occupations\', \'ibz_k_points\', \'k_point_weights\']'
+        assert mode in ['eigenvalues', 'occupations', 'ibz_k_points',
+                        'k_point_weights'], mode
         if self.get_spin_polarized():
             spin = {0: 1, 1: 0}[spin]
         if spin == 0:
-           spinname = ''
+            spinname = ''
         else:
-           spinname = 'SPIN UP'.lower()
+            spinname = 'SPIN UP'.lower()
         # number of lines of eigenvalues/occupations for a kpt
         nband = self.get_number_of_bands()
         n_entries_float = 8  # float entries per line
