@@ -14,17 +14,19 @@ all_properties = ['energy', 'forces', 'stress', 'dipole',
                   'charges', 'magmom', 'magmoms']
 
 
-all_changes = ['positions', 'numbers', 'cell', 'pbc', 'charges', 'magmoms']
+all_changes = ['positions', 'numbers', 'cell', 'pbc',
+               'initial_charges', 'initial_magmoms']
 
 
 # Recognized names of calculators sorted alphabetically:
-names = ['abinit', 'aims', 'asap', 'castep', 'dftb', 'eam', 'elk', 'emt',
-         'exciting', 'fleur', 'gpaw', 'gaussian', 'hotbit', 'jacapo',
-         'lammps', 'lammpslib', 'lj', 'mopac', 'morse',
+names = ['abinit', 'aims', 'asap', 'castep', 'cp2k', 'dftb', 'eam', 'elk',
+         'emt', 'exciting', 'fleur', 'gaussian', 'gpaw', 'gromacs', 'hotbit',
+         'jacapo', 'lammps', 'lammpslib', 'lj', 'mopac', 'morse',
          'nwchem', 'siesta', 'turbomole', 'vasp']
 
 
-special = {'eam': 'EAM',
+special = {'cp2k': 'CP2K',
+           'eam': 'EAM',
            'elk': 'ELK',
            'emt': 'EMT',
            'fleur': 'FLEUR',
@@ -73,9 +75,9 @@ def kptdensity2monkhorstpack(atoms, kptdensity=3.5, even=True):
     atoms: Atoms object
         Contains unit cell and information about boundary conditions.
     kptdensity: float
-        K-point density.  Default value is 3.5 point per Ang^-1.
+        Required k-point density.  Default value is 3.5 point per Ang^-1.
     even: bool
-        Round to even numbers.
+        Round up to even numbers.
     """
 
     recipcell = atoms.get_reciprocal_cell()
@@ -84,9 +86,9 @@ def kptdensity2monkhorstpack(atoms, kptdensity=3.5, even=True):
         if atoms.pbc[i]:
             k = 2 * pi * sqrt((recipcell[i]**2).sum()) * kptdensity
             if even:
-                kpts.append(max(1, 2 * int(round(k / 2))))
+                kpts.append(2 * int(np.ceil(k / 2)))
             else:
-                kpts.append(max(1, int(round(k))))
+                kpts.append(int(np.ceil(k)))
         else:
             kpts.append(1)
     return np.array(kpts)
@@ -149,7 +151,7 @@ class Calculator:
     """
 
     implemented_properties = []
-    "Properties calculator can handle (energy, forces, ...)"
+    'Properties calculator can handle (energy, forces, ...)'
 
     default_parameters = {}
     'Default parameters'
@@ -162,7 +164,7 @@ class Calculator:
             Prefix for restart file.  May contain a directory.  Default
             is None: don't restart.
         ignore_bad_restart_file: bool
-            Ignore broken or missing restart file.  By defauls, it is an
+            Ignore broken or missing restart file.  By default, it is an
             error if the restart file is missing or broken.
         label: str
             Name used for all files.  May contain a directory.
@@ -208,7 +210,7 @@ class Calculator:
         self.set(**kwargs)
 
         if not hasattr(self, 'name'):
-            self.name = self.__class__.__name__
+            self.name = self.__class__.__name__.lower()
 
     def set_label(self, label):
         """Set label and convert label to directory and prefix.
@@ -334,10 +336,10 @@ class Calculator:
                 system_changes.append('pbc')
             if not equal(self.atoms.get_initial_magnetic_moments(),
                          atoms.get_initial_magnetic_moments(), tol):
-                system_changes.append('magmoms')
+                system_changes.append('initial_magmoms')
             if not equal(self.atoms.get_initial_charges(),
                          atoms.get_initial_charges(), tol):
-                system_changes.append('charges')
+                system_changes.append('initial_charges')
 
         return system_changes
 
@@ -349,13 +351,13 @@ class Calculator:
             return energy
 
     def get_forces(self, atoms=None):
-        return self.get_property('forces', atoms).copy()
+        return self.get_property('forces', atoms)
 
     def get_stress(self, atoms=None):
-        return self.get_property('stress', atoms).copy()
+        return self.get_property('stress', atoms)
 
     def get_dipole_moment(self, atoms=None):
-        return self.get_property('dipole', atoms).copy()
+        return self.get_property('dipole', atoms)
 
     def get_charges(self, atoms=None):
         return self.get_property('charges', atoms)
@@ -364,9 +366,9 @@ class Calculator:
         return self.get_property('magmom', atoms)
 
     def get_magnetic_moments(self, atoms=None):
-        return self.get_property('magmoms', atoms).copy()
+        return self.get_property('magmoms', atoms)
 
-    def get_property(self, name, atoms=None):
+    def get_property(self, name, atoms=None, allow_calculation=True):
         if name not in self.implemented_properties:
             raise NotImplementedError
 
@@ -379,6 +381,8 @@ class Calculator:
                 self.reset()
 
         if name not in self.results:
+            if not allow_calculation:
+                return None
             try:
                 self.calculate(atoms, [name], system_changes)
             except Exception:
@@ -391,7 +395,10 @@ class Calculator:
         if name == 'magmoms' and 'magmoms' not in self.results:
             return np.zeros(len(atoms))
 
-        return self.results[name]
+        result = self.results[name]
+        if isinstance(result, np.ndarray):
+            result = result.copy()
+        return result
 
     def calculation_required(self, atoms, properties):
         system_changes = self.check_state(atoms)
@@ -413,7 +420,7 @@ class Calculator:
         system_changes: list of str
             List of what has changed since last calculation.  Can be
             any combination of these five: 'positions', 'numbers', 'cell',
-            'pbc', 'charges' and 'magmoms'.
+            'pbc', 'initial_charges' and 'initial_magmoms'.
 
         Subclasses need to implement this, but can ignore properties
         and system_changes if they want.  Calculated properties should
@@ -449,7 +456,7 @@ class Calculator:
 
 
 class FileIOCalculator(Calculator):
-    "Base class for calculators that write input files and read output files."
+    """Base class for calculators that write/read input/output files."""
 
     command = None
     'Command used to start calculation'
