@@ -11,7 +11,7 @@ import os
 import numpy as np
 from ase.test import NotAvailable
 from ase.calculators.neighborlist import NeighborList
-from ase.calculators.calculator import Calculator
+from ase.calculators.calculator import Calculator, all_changes
 from scipy.interpolate import InterpolatedUnivariateSpline as spline
 
 
@@ -51,7 +51,7 @@ The total energy `E_{\rm tot}` of an arbitrary arrangement of atoms is
 given by the EAM potential as
 
 .. math::
-   E_{\rm tot} = \sum_i F(\bar\rho_i) + \frac{1}{2}\sum_{i\ne j} \phi(r_{ij})
+   E_\text{tot} = \sum_i F(\bar\rho_i) + \frac{1}{2}\sum_{i\ne j} \phi(r_{ij})
 
 and
 
@@ -69,10 +69,10 @@ atom and its neighbour for that bond.
 The ADP potential is defined as
 
 .. math::
-   E_{\rm tot} = \sum_i F(\bar\rho_i) + \frac{1}{2}\sum_{i\ne j} \phi(r_{ij})
-   + {1\over 2} \sum_{i,\alpha} (\mu_i^\alpha)^2
-   + {1\over 2} \sum_{i,\alpha,\beta} (\lambda_i^{\alpha\beta})^2
-   - {1 \over 6} \sum_i \nu_i^2
+   E_\text{tot} = \sum_i F(\bar\rho_i) + \frac{1}{2}\sum_{i\ne j} \phi(r_{ij})
+   + \frac{1}{2} \sum_{i,\alpha} (\mu_i^\alpha)^2
+   + \frac{1}{2} \sum_{i,\alpha,\beta} (\lambda_i^{\alpha\beta})^2
+   - \frac{1}{6} \sum_i \nu_i^2
 
 where `\mu_i^\alpha` is the dipole vector, `\lambda_i^{\alpha\beta}`
 is the quadrupole tensor and `\nu_i` is the trace of
@@ -220,10 +220,12 @@ End EAM Interface Documentation
     default_parameters = dict(
         skin=1.0,
         potential=None,
-        header="""EAM/ADP potential file\nGenerated from eam.py\nblank\n""")
+        header=[b'EAM/ADP potential file\n',
+                b'Generated from eam.py\n',
+                b'blank\n'])
 
     def __init__(self, restart=None, ignore_bad_restart_file=False,
-                  label=os.curdir, atoms=None, **kwargs):
+                 label=os.curdir, atoms=None, **kwargs):
 
         if 'potential' in kwargs:
             self.read_potential(kwargs['potential'])
@@ -240,7 +242,7 @@ End EAM Interface Documentation
                       'skin', 'form', 'Z', 'nr', 'nrho', 'mass')
 
         # set any additional keyword arguments
-        for arg, val in self.parameters.iteritems():
+        for arg, val in self.parameters.items():
             if arg in valid_args:
                 setattr(self, arg, val)
             else:
@@ -283,7 +285,7 @@ End EAM Interface Documentation
 
         self.Nelements = int(data[0])
         d = 1
-        self.elements = data[d:(d + self.Nelements)]
+        self.elements = data[d:d + self.Nelements]
         d += self.Nelements
 
         self.nrho = int(data[d])
@@ -317,8 +319,8 @@ End EAM Interface Documentation
         self.rphi_data = np.zeros([self.Nelements, self.Nelements, self.nr])
 
         for i in range(self.Nelements):
-            for j in range(i, self.Nelements):
-                self.rphi_data[i, j] = np.float_(data[d:(d + self.nr)])
+            for j in range(i + 1):
+                self.rphi_data[j, i] = np.float_(data[d:(d + self.nr)])
                 d += self.nr
 
         self.r = np.arange(0, self.nr) * self.dr
@@ -396,15 +398,15 @@ End EAM Interface Documentation
         self.d_data = np.zeros([self.Nelements, self.Nelements, self.nr])
         # should be non symetrical combinations of 2
         for i in range(self.Nelements):
-            for j in range(i, self.Nelements):
-                self.d_data[i, j] = data[d:d + self.nr]
+            for j in range(i + 1):
+                self.d_data[j, i] = data[d:d + self.nr]
                 d += self.nr
 
         self.q_data = np.zeros([self.Nelements, self.Nelements, self.nr])
         # should be non symetrical combinations of 2
         for i in range(self.Nelements):
-            for j in range(i, self.Nelements):
-                self.q_data[i, j] = data[d:d + self.nr]
+            for j in range(i + 1):
+                self.q_data[j, i] = data[d:d + self.nr]
                 d += self.nr
 
     def write_potential(self, filename, nc=1, numformat='%.8e'):
@@ -413,7 +415,7 @@ End EAM Interface Documentation
         wide.  Note: array lengths need to be an exact multiple of nc
         """
 
-        f = open(filename, 'w')
+        f = open(filename, 'wb')
 
         assert self.nr % nc == 0
         assert self.nrho % nc == 0
@@ -421,13 +423,12 @@ End EAM Interface Documentation
         for line in self.header:
             f.write(line)
 
-        f.write('%d ' % self.Nelements)
-        for i in range(self.Nelements):
-            f.write('%s ' % str(self.elements[i]))
-        f.write('\n')
+        f.write('{0} '.format(self.Nelements).encode())
+        f.write(' '.join(self.elements).encode() + b'\n')
 
-        f.write('%d %f %d %f %f \n' %
-                (self.nrho, self.drho, self.nr, self.dr, self.cutoff))
+        f.write(('%d %f %d %f %f \n' %
+                 (self.nrho, self.drho, self.nr,
+                  self.dr, self.cutoff)).encode())
 
         # start of each section for each element
 #        rs = np.linspace(0, self.nr * self.dr, self.nr)
@@ -437,14 +438,15 @@ End EAM Interface Documentation
         rhos = np.arange(0, self.nrho) * self.drho
 
         for i in range(self.Nelements):
-            f.write('%d %f %f %s\n' % (self.Z[i], self.mass[i],
-                                       self.a[i], str(self.lattice[i])))
+            f.write(('%d %f %f %s\n' %
+                     (self.Z[i], self.mass[i],
+                      self.a[i], str(self.lattice[i]))).encode())
             np.savetxt(f,
-                       self.embedded_energy[i](rhos).reshape(self.nrho / nc,
+                       self.embedded_energy[i](rhos).reshape(self.nrho // nc,
                                                              nc),
                        fmt=nc * [numformat])
             np.savetxt(f,
-                       self.electron_density[i](rs).reshape(self.nr / nc,
+                       self.electron_density[i](rs).reshape(self.nr // nc,
                                                             nc),
                        fmt=nc * [numformat])
 
@@ -453,7 +455,7 @@ End EAM Interface Documentation
         for i in range(self.Nelements):
             for j in range(i, self.Nelements):
                 np.savetxt(f,
-                           (rs * self.phi[i, j](rs)).reshape(self.nr / nc,
+                           (rs * self.phi[i, j](rs)).reshape(self.nr // nc,
                                                              nc),
                            fmt=nc * [numformat])
 
@@ -500,8 +502,7 @@ End EAM Interface Documentation
         self.neighbors.update(atoms)
 
     def calculate(self, atoms=None, properties=['energy'],
-                  system_changes=['positions', 'numbers', 'cell',
-                                  'pbc', 'charges','magmoms']):
+                  system_changes=all_changes):
         """EAM Calculator
 
         atoms: Atoms object
@@ -512,7 +513,7 @@ End EAM Interface Documentation
         system_changes: list of str
             List of what has changed since last calculation.  Can be
             any combination of these five: 'positions', 'numbers', 'cell',
-            'pbc', 'charges' and 'magmoms'.
+            'pbc', 'initial_charges' and 'initial_magmoms'.
             """
 
         Calculator.calculate(self, atoms, properties, system_changes)
@@ -563,7 +564,7 @@ End EAM Interface Documentation
             rvec = (atoms.positions[neighbors] + offset -
                     atoms.positions[i])
 
-            ## calculate the distance to the nearest neighbors
+            # calculate the distance to the nearest neighbors
             r = np.sqrt(np.sum(np.square(rvec), axis=1))  # fast
 #            r = np.apply_along_axis(np.linalg.norm, 1, rvec)  # sloow
 
@@ -573,7 +574,7 @@ End EAM Interface Documentation
                 if not use.any():
                     continue
                 pair_energy += np.sum(self.phi[self.index[i], j_index](
-                        r[nearest][use])) / 2.
+                    r[nearest][use])) / 2.
 
                 density = np.sum(
                     self.electron_density[j_index](r[nearest][use]))
@@ -794,5 +795,3 @@ End EAM Interface Documentation
                 label = name + ' ' + self.elements[i] + '-' + self.elements[j]
                 plt.plot(curvex, curvey[i, j](curvex), label=label)
         plt.legend()
-
-#print 'done eam'
