@@ -1,11 +1,9 @@
 from math import pi
-import pickle
 
 import numpy as np
 
 from ase.atoms import Atoms
-from ase.parallel import world, rank, distribute_cpus
-from ase.utils import opencew
+from ase.calculators.calculator import Calculator
 
 
 def make_test_dft_calculation():
@@ -86,10 +84,25 @@ class TestCalculator:
 
     def get_fermi_level(self):
         return 0.0
+    
+    def get_pseudo_density(self):
+        n = 0.0
+        for w, eps, psi in zip(self.weights, self.eps[:, 0], self.psi):
+            if eps >= 0.0:
+                continue
+            n += w * (psi * psi.conj()).real
 
+        n[1:] += n[:0:-1].copy()
+        n[:, 1:] += n[:, :0:-1].copy()
+        n += n.transpose((1, 0, 2)).copy()
+        n /= 8
+        return n
 
-class TestPotential:
-    def get_forces(self, atoms):
+        
+class TestPotential(Calculator):
+    implemented_properties = ['energy', 'forces']
+    def calculate(self, atoms, properties, system_changes):
+        Calculator.calculate(self, atoms, properties, system_changes)
         E = 0.0
         R = atoms.positions
         F = np.zeros_like(R)
@@ -100,15 +113,8 @@ class TestPotential:
             E += np.vdot(x, x)
             d[a] = 1
             F -= (x / d)[:, None] * D
-        self.energy = 0.25 * E
-        return F
-
-    def get_potential_energy(self, atoms):
-        self.get_forces(atoms)
-        return self.energy
-
-    def get_stress(self, atoms):
-        raise NotImplementedError
+        energy = 0.25 * E
+        self.results = {'energy': energy, 'forces': F}
 
 
 def numeric_force(atoms, a, i, d=0.001):
@@ -124,63 +130,3 @@ def numeric_force(atoms, a, i, d=0.001):
     eminus = atoms.get_potential_energy()
     atoms.positions[a, i] = p0
     return (eminus - eplus) / (2 * d)
-
-
-def numeric_forces(atoms, indices=None, axes=(0, 1, 2), d=0.001,
-                   parallel=None, name=None):
-    """Evaluate finite-difference forces on several atoms.
-
-    Returns an array of forces for each specified atomic index and
-    each specified axis, calculated using finite difference on each
-    atom and direction separately.  Array has same shape as if
-    returned from atoms.get_forces(); uncalculated elements are zero.
-
-    Calculates all forces by default."""
-
-    if indices is None:
-        indices = range(len(atoms))
-    F_ai = np.zeros_like(atoms.positions)
-    n = len(indices) * len(axes)
-    if parallel is None:
-        atom_tasks = [atoms] * n
-        master = True
-        calc_comm = world
-    else:
-        calc_comm, tasks_comm, tasks_rank = distribute_cpus(parallel, world)
-        master = calc_comm.rank == 0
-        calculator = atoms.get_calculator()
-        calculator.set(communicator=calc_comm)
-        atom_tasks = [None] * n
-        for i in range(n):
-            if ((i - tasks_rank) % tasks_comm.size) == 0:
-                atom_tasks[i] = atoms
-    for ia, a in enumerate(indices):
-        for ii, i in enumerate(axes):
-            atoms = atom_tasks[ia * len(axes) + ii]
-            if atoms is not None:
-                done = 0
-                if name:
-                    fname = '%s.%d%s.pckl' % (name, a, 'xyz'[i])
-                    fd = opencew(fname, calc_comm)
-                    if fd is None:
-                        if master:
-                            try:
-                                F_ai[a, i] = pickle.load(open(fname))
-                                print '# atom', a, 'xyz'[i], 'done'
-                                done = 1
-                            except EOFError:
-                                pass
-                        done = calc_comm.sum(done)
-                if not done:
-                    print '# rank', rank, 'calculating atom', a, 'xyz'[i]
-                    force = numeric_force(atoms, a, i, d)
-                    if master:
-                        F_ai[a, i] = force
-                        if name:
-                            fd = open('%s.%d%s.pckl' % (name, a, 'xyz'[i]),
-                                      'w')
-                            pickle.dump(force, fd)
-                            fd.close()
-    if parallel is not None:
-        world.sum(F_ai)
-    return F_ai
