@@ -1,9 +1,9 @@
 from ase.data import atomic_numbers, chemical_symbols, reference_states
 from ase.units import *
 
-import fcc
-import hcp
-import au
+from . import fcc
+from . import hcp
+from . import au
 
 lattice = {'fcc': fcc.data,
            'hcp': hcp.data,
