@@ -1,6 +1,6 @@
 # Generated: 2011-12-19
 # doi:10.1063/1.2162161, experimental geometries if available, dimers only
-from numpy import array
+from numpy import array, nan
 data = {
     'H': {'charges': None,
           'database': 'TMFP06D',
@@ -108,6 +108,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  3.905],
                               ]),
+           'dissociation energy': 12.0,
+           'harmonic frequency': 92,
            'symbols': 'KK'},
     'Ca2': {'charges': None,
            'database': 'TMFP06D',
@@ -117,6 +119,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  4.277],
                               ]),
+           'dissociation energy': 3.1,
+           'harmonic frequency': 65,
            'symbols': 'CaCa'},
     'Sc2': {'charges': None,
            'database': 'TMFP06D',
@@ -126,6 +130,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  2.74], # from 10.1063/1.480546 (MRSDQCI)
                               ]),
+           'dissociation energy': 38.4,
+           'harmonic frequency': 239,
            'symbols': 'ScSc'},
     'Ti2': {'charges': None,
            'database': 'TMFP06D',
@@ -135,6 +141,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.943],
                               ]),
+           'dissociation energy': 36.1,
+           'harmonic frequency': 408,
            'symbols': 'TiTi'},
     'V2': {'charges': None,
            'database': 'TMFP06D',
@@ -144,6 +152,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.77], # ref. a
                               ]),
+           'dissociation energy': 64.3,
+           'harmonic frequency': 538,
            'symbols': 'VV'},
     'Cr2': {'charges': None,
            'database': 'TMFP06D',
@@ -153,6 +163,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.679],
                               ]),
+           'dissociation energy': 33.9,
+           'harmonic frequency': 481,
            'symbols': 'CrCr'},
     'Mn2': {'charges': None,
            'database': 'TMFP06D',
@@ -162,6 +174,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  3.40],
                               ]),
+           'dissociation energy': 18.8,
+           'harmonic frequency': 340,
            'symbols': 'MnMn'},
     'Fe2': {'charges': None,
            'database': 'TMFP06D',
@@ -171,6 +185,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  2.02],
                               ]),
+           'dissociation energy': 26.9,
+           'harmonic frequency': 300,
            'symbols': 'FeFe'},
     # exp. geometry not given in ref.
     'Co2': {'charges': None,
@@ -181,6 +197,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.98], # calculated doi:10.1063/1.1788656
                               ]),
+           'dissociation energy': 39.4,
+           'harmonic frequency': 297,
            'symbols': 'CoCo'},
     'Ni2': {'charges': None,
            'database': 'TMFP06D',
@@ -190,6 +208,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  2.155],
                               ]),
+           'dissociation energy': 48.1,
+           'harmonic frequency': 259,
            'symbols': 'NiNi'},
     'Cu2': {'charges': None,
            'database': 'TMFP06D',
@@ -199,6 +219,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  2.219],
                               ]),
+           'dissociation energy': 46.7,
+           'harmonic frequency': 266,
            'symbols': 'CuCu'},
     'Zn2': {'charges': None,
            'database': 'TMFP06D',
@@ -208,6 +230,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  2.35], # ref. j
                               ]),
+           'dissociation energy': 0.80,
+           'harmonic frequency': 25.9,
            'symbols': 'ZnZn'},
     #
     'KH': {'charges': None,
@@ -218,6 +242,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  2.243],
                               ]),
+           'dissociation energy': 42.2,
+           'harmonic frequency': 707,
            'symbols': 'KH'},
     'CaH': {'charges': None,
            'database': 'TMFP06D',
@@ -227,6 +253,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  2.003],
                               ]),
+           'dissociation energy': 41.0,
+           'harmonic frequency': 1298,
            'symbols': 'CaH'},
     # exp. geometry not given in ref.
     'ScH': {'charges': None,
@@ -237,6 +265,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.775], # doi: 10.1063/1.3489110
                               ]),
+           'dissociation energy': 47.5,
+           'harmonic frequency': nan,
            'symbols': 'ScH'},
     'TiH': {'charges': None,
            'database': 'TMFP06D',
@@ -246,6 +276,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.779],
                               ]),
+           'dissociation energy': 50.0,
+           'harmonic frequency': 1405,
            'symbols': 'TiH'},
     'CrH': {'charges': None,
            'database': 'TMFP06D',
@@ -255,6 +287,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.656],
                               ]),
+           'dissociation energy': 46.8,
+           'harmonic frequency': 1581,
            'symbols': 'CrH'},
     'MnH': {'charges': None,
            'database': 'TMFP06D',
@@ -264,6 +298,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.731],
                               ]),
+           'dissociation energy': 31.1,
+           'harmonic frequency': 1548,
            'symbols': 'MnH'},
     'FeH': {'charges': None,
            'database': 'TMFP06D',
@@ -273,6 +309,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.589],
                               ]),
+           'dissociation energy': 39.2,
+           'harmonic frequency': 1827,
            'symbols': 'FeH'},
     'CoH': {'charges': None,
            'database': 'TMFP06D',
@@ -282,6 +320,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.52],
                               ]),
+           'dissociation energy': 48.4,
+           'harmonic frequency': 1925,
            'symbols': 'CoH'},
     'NiH': {'charges': None,
            'database': 'TMFP06D',
@@ -291,6 +331,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.475],
                               ]),
+           'dissociation energy': 61.3,
+           'harmonic frequency': 1927,
            'symbols': 'NiH'},
     'CuH': {'charges': None,
            'database': 'TMFP06D',
@@ -300,6 +342,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.463],
                               ]),
+           'dissociation energy': 63.4,
+           'harmonic frequency': 1941,
            'symbols': 'CuH'},
     #
     'ScN': {'charges': None,
@@ -310,6 +354,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.687],
                               ]),
+           'dissociation energy': 113,
+           'harmonic frequency': 795,
            'symbols': 'ScN'},
     'TiN': {'charges': None,
            'database': 'TMFP06D',
@@ -319,6 +365,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.57],
                               ]),
+           'dissociation energy': 124,
+           'harmonic frequency': 1033,
            'symbols': 'TiN'},
     'VN': {'charges': None,
            'database': 'TMFP06D',
@@ -328,6 +376,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.57],
                               ]),
+           'dissociation energy': 117,
+           'harmonic frequency': 1033,
            'symbols': 'VN'},
     'CrN': {'charges': None,
            'database': 'TMFP06D',
@@ -337,6 +387,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.563],
                               ]),
+           'dissociation energy': 97,
+           'harmonic frequency': 1050,
            'symbols': 'CrN'},
     #
     'CaO': {'charges': None,
@@ -347,6 +399,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.822],
                               ]),
+           'dissociation energy': 110.8,
+           'harmonic frequency': 732,
             'symbols': 'CaO'},
     'ScO': {'charges': None,
            'database': 'TMFP06D',
@@ -356,6 +410,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.668],
                               ]),
+           'dissociation energy': 163.0,
+           'harmonic frequency': 965,
             'symbols': 'ScO'},
     'TiO': {'charges': None,
            'database': 'TMFP06D',
@@ -365,6 +421,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.620],
                               ]),
+           'dissociation energy': 161.0,
+           'harmonic frequency': 1009,
             'symbols': 'TiO'},
     'VO': {'charges': None,
            'database': 'TMFP06D',
@@ -374,6 +432,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.589],
                               ]),
+           'dissociation energy': 150.0,
+           'harmonic frequency': 1011,
             'symbols': 'VO'},
     'CrO': {'charges': None,
            'database': 'TMFP06D',
@@ -383,6 +443,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.615],
                               ]),
+           'dissociation energy': 103.0,
+           'harmonic frequency': 898,
             'symbols': 'CrO'},
     'MnO': {'charges': None,
            'database': 'TMFP06D',
@@ -392,6 +454,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.646],
                               ]),
+           'dissociation energy': 89.5,
+           'harmonic frequency': 840,
             'symbols': 'MnO'},
     'FeO': {'charges': None,
            'database': 'TMFP06D',
@@ -401,6 +465,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.616],
                               ]),
+           'dissociation energy': 97.4,
+           'harmonic frequency': 880,
             'symbols': 'FeO'},
     'CoO': {'charges': None,
            'database': 'TMFP06D',
@@ -410,6 +476,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.629],
                               ]),
+           'dissociation energy': 92.1,
+           'harmonic frequency': 853,
             'symbols': 'CoO'},
     'NiO': {'charges': None,
            'database': 'TMFP06D',
@@ -419,6 +487,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.627],
                               ]),
+           'dissociation energy': 90.4,
+           'harmonic frequency': 838,
             'symbols': 'NiO'},
     'CuO': {'charges': None,
            'database': 'TMFP06D',
@@ -428,6 +498,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.724],
                               ]),
+           'dissociation energy': 66.6,
+           'harmonic frequency': 640,
             'symbols': 'CuO'},
     # ZnO not in ref. Taken for completeness from doi: 10.1063/1.3489110
     'ZnO': {'charges': None,
@@ -438,6 +510,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.724],
                               ]),
+           'dissociation energy': nan,
+           'harmonic frequency': nan,
            'symbols': 'ZnO'},
     #
     'KF': {'charges': None,
@@ -448,6 +522,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  2.171],
                               ]),
+           'dissociation energy': 117.5,
+           'harmonic frequency': 428,
             'symbols': 'KF'},
     'CaF': {'charges': None,
            'database': 'TMFP06D',
@@ -457,6 +533,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.967],
                               ]),
+           'dissociation energy': 127.2,
+           'harmonic frequency': 581,
             'symbols': 'CaF'},
     'ScF': {'charges': None,
            'database': 'TMFP06D',
@@ -466,6 +544,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.788],
                               ]),
+           'dissociation energy': 143.3,
+           'harmonic frequency': 736,
             'symbols': 'ScF'},
     'TiF': {'charges': None,
            'database': 'TMFP06D',
@@ -475,6 +555,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.834],
                               ]),
+           'dissociation energy': 137,
+           'harmonic frequency': nan,
             'symbols': 'TiF'},
     'CrF': {'charges': None,
            'database': 'TMFP06D',
@@ -484,6 +566,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.784],
                               ]),
+           'dissociation energy': 106.3,
+           'harmonic frequency': 664,
             'symbols': 'CrF'},
     'FeF': {'charges': None,
            'database': 'TMFP06D',
@@ -493,6 +577,8 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.780],
                               ]),
+           'dissociation energy': nan,
+           'harmonic frequency': 663,
             'symbols': 'FeF'},
     'CuF': {'charges': None,
            'database': 'TMFP06D',
@@ -502,5 +588,7 @@ data = {
                               [ 0.,  0.,  0.],
                               [ 0.,  0.,  1.745],
                               ]),
+           'dissociation energy': 102.8,
+           'harmonic frequency': 623,
             'symbols': 'CuF'},
     }
