@@ -4,7 +4,7 @@ import numpy as np
 
 
 class STM:
-    def __init__(self, atoms, symmetries=None):
+    def __init__(self, atoms, symmetries=None, use_density=False):
         """Scanning tunneling microscope.
 
         atoms: Atoms object or filename
@@ -17,12 +17,17 @@ class STM:
 
                  [-1  0]   [ 1  0]   [ 0  1]
                  [ 0  1]   [ 0 -1]   [ 1  0]
-        """	
+                 
+        use_density: bool
+            Use the electron density instead of the LDOS.
+        """
 
+        self.use_density = use_density
+        
         if isinstance(atoms, str):
-           with open(atoms, 'rb') as f:
-               self.ldos, self.bias, self.cell = pickle.load(f)
-           self.atoms = None
+            with open(atoms, 'rb') as f:
+                self.ldos, self.bias, self.cell = pickle.load(f)
+            self.atoms = None
         else:
             self.atoms = atoms
             self.cell = atoms.cell
@@ -37,6 +42,14 @@ class STM:
         if self.ldos is not None and bias == self.bias:
             return
 
+        self.bias = bias
+
+        calc = self.atoms.calc
+
+        if self.use_density:
+            self.ldos = calc.get_pseudo_density()
+            return
+            
         if bias < 0:
             emin = bias
             emax = 0.0
@@ -44,8 +57,6 @@ class STM:
             emin = 0
             emax = bias
 
-        calc = self.atoms.calc
-
         nbands = calc.get_number_of_bands()
         weights = calc.get_k_point_weights()
         nkpts = len(weights)
@@ -79,7 +90,6 @@ class STM:
             ldos *= 0.5
             
         self.ldos = ldos
-        self.bias = bias
 
     def write(self, filename='stm.pckl'):
         """Write local density of states to pickle file."""
@@ -184,7 +194,7 @@ def interpolate(q, heights):
      
 def find_height(ldos, current, h, z0=None):
     if z0 is None:
-        n = len(ldos) - 1
+        n = len(ldos) - 2
     else:
         n = int(z0 / h)
     while n >= 0:
@@ -192,7 +202,7 @@ def find_height(ldos, current, h, z0=None):
             break
         n -= 1
     else:
-        raise RuntimeError('Tip crash!')
+        return 0.0
 
     c2, c1 = ldos[n:n + 2]
     return (n + 1 - (current - c1) / (c2 - c1)) * h
