@@ -1,5 +1,5 @@
 """ This is a module to handle generic ASE (gui) defaults from a ~/.ase/gui.py configuration file, if it exists.
-It is imported when opening ag and can then be modified at runtime, if necessary.
+It is imported when opening ase-gui and can then be modified at runtime, if necessary.
 syntax for each entry:
 
 gui_default_settings['key'] = value
@@ -18,5 +18,5 @@ def read_defaults():
     name = os.path.expanduser('~/.ase/gui.py')
     config = gui_default_settings
     if os.path.exists(name):
-        execfile(name)
+        exec(compile(open(name).read(), name, 'exec'))
     return config
