@@ -142,6 +142,8 @@ class HomogeneousDeformation(Simulation, MinimizeMixin, OutputFieldMixin):
         outframe = self.makeoutputfield(None, 
                                         heading=_("Strain\t\tEnergy [eV]"))
         fitframe = gtk.Frame(_("Fit:"))
+        fitframe.set_size_request(100,150)
+
         vbox2 = gtk.VBox()
         vbox2.show()
         fitframe.add(vbox2)
@@ -198,7 +200,7 @@ class HomogeneousDeformation(Simulation, MinimizeMixin, OutputFieldMixin):
         x, y = self.scrwin.get_children()[0].size_request() 
         x += self.scrwin.get_vscrollbar().size_request()[0] + 5
         y += self.scrwin.get_hscrollbar().size_request()[1] + 5
-        print x,y 
+
         if resize: 
             xdef, ydef = self.get_default_size() 
             xnow, ynow = self.get_size() 
@@ -324,7 +326,7 @@ class HomogeneousDeformation(Simulation, MinimizeMixin, OutputFieldMixin):
                 deformation = np.diag(1.0 + d * deform_axes)
                 self.atoms.set_cell(np.dot(undef_cell, deformation),
                                     scale_atoms=True)
-                if self.gui.simulation.has_key('progress'):
+                if 'progress' in self.gui.simulation:
                     self.gui.simulation['progress'].set_scale_progress(i)
                 if self.radio_relax_on.get_active():
                     algo = getattr(ase.optimize, mininame)
@@ -366,7 +368,7 @@ class HomogeneousDeformation(Simulation, MinimizeMixin, OutputFieldMixin):
                     self.atoms.set_cell(np.dot(undef_cell, deformation),
                                         scale_atoms=True)
                     if self.radio_relax_on.get_active():
-                        if self.gui.simulation.has_key('progress'):
+                        if 'progress' in self.gui.simulation:
                             self.gui.simulation['progress'].set_scale_progress(
                                 len(steps))
                         algo = getattr(ase.optimize, mininame)
