@@ -19,6 +19,7 @@ from ase.gui.defaults import read_defaults
 from ase.utils import rotate
 from ase.quaternions import Quaternion
 
+
 class View:
     def __init__(self, vbox, rotations):
         self.colormode = 'jmol'  # The default colors
@@ -97,7 +98,9 @@ class View:
 
             filenames = self.images.filenames
             filename = filenames[frame]
-            if self.frame is None or filename != filenames[self.frame] or filename is None:
+            if (self.frame is None or
+                filename != filenames[self.frame] or
+                filename is None):
                 if filename is None:
                     filename = 'ase.gui'
             filename = basename(filename)
@@ -193,12 +196,16 @@ class View:
                         pbc=self.images.pbc))
         nb = nl.nneighbors + nl.npbcneighbors
         self.bonds = np.empty((nb, 5), int)
+        self.coordination = np.zeros((self.images.natoms), dtype=int)
         if nb == 0:
             return
         
         n1 = 0
         for a in range(self.images.natoms):
             indices, offsets = nl.get_neighbors(a)
+            self.coordination[a] += len(indices)
+            for a2 in indices:
+                self.coordination[a2] += 1
             n2 = n1 + len(indices)
             self.bonds[n1:n2, 0] = a
             self.bonds[n1:n2, 1] = indices
@@ -218,17 +225,18 @@ class View:
         self.menu_change = 1
         self.atoms_to_rotate = None
         for c_mode in ['Rotate', 'Orient', 'Move']:
-              self.ui.get_widget('/MenuBar/ToolsMenu/%sAtoms' % c_mode).set_active(False)
+            self.ui.get_widget('/MenuBar/ToolsMenu/%sAtoms' %
+                               c_mode).set_active(False)
         self.light_green_markings = 0
-        self.menu_change = 0        
+        self.menu_change = 0
         self.draw()
         
-                      
     def toggle_mode(self, mode):
         self.menu_change = 1
         i_sum = 0
         for c_mode in ['Rotate', 'Orient', 'Move']:
-            i_sum += self.ui.get_widget('/MenuBar/ToolsMenu/%sAtoms' % c_mode).get_active() 
+            i_sum += self.ui.get_widget('/MenuBar/ToolsMenu/%sAtoms' %
+                                        c_mode).get_active()
         if i_sum == 0 or (i_sum == 1 and sum(self.images.selected) == 0):
             self.reset_tools_modes()
             return()
@@ -243,30 +251,35 @@ class View:
 
         for c_mode in ['Rotate', 'Orient', 'Move']:
             if c_mode != mode:
-                  self.ui.get_widget('/MenuBar/ToolsMenu/%sAtoms' % c_mode).set_active(False) 
+                self.ui.get_widget('/MenuBar/ToolsMenu/%sAtoms' %
+                                   c_mode).set_active(False)
         
-        if self.ui.get_widget('/MenuBar/ToolsMenu/%sAtoms' % mode).get_active():
+        if self.ui.get_widget('/MenuBar/ToolsMenu/%sAtoms' %
+                              mode).get_active():
             self.atoms_to_rotate_0 = self.images.selected.copy()
             for i in range(len(self.images.selected)):
-               self.images.selected[i] = False
+                self.images.selected[i] = False
             self.light_green_markings = 1
         else:
-            try: 
+            try:
                 atr = self.atoms_to_rotate_0
                 for i in range(len(self.images.selected)):
                     self.images.selected[i] = atr[i]
             except:
-                pass                
+                pass
                 
         self.menu_change = 0
         self.draw()
                       
     def toggle_move_mode(self, action):
         """
-        Toggles the move mode, where the selected atoms can be moved with the arrow
-        keys and pg up/dn. If the shift key is pressed, the movement will be reduced.
+        Toggles the move mode, where the selected atoms
+        can be moved with the arrow
+        keys and pg up/dn. If the shift key is pressed,
+        the movement will be reduced.
         
-        The movement will be relative to the current rotation of the coordinate system.
+        The movement will be relative to the current
+        rotation of the coordinate system.
         
         The implementation of the move mode is found in the gui.scroll
         """
@@ -305,7 +318,7 @@ class View:
         self.orient_normal = np.array([1.0, 0.0, 0.0])
         sel_pos = []
         for i, j in enumerate(self.atoms_to_rotate_0):
-            if j: 
+            if j:
                 sel_pos.append(self.R[i])
         if len(sel_pos) == 2:
             self.orient_normal = sel_pos[0] - sel_pos[1]
@@ -318,7 +331,7 @@ class View:
     def show_labels(self, action, active):
         an = active.get_name()
         if an == "AtomIndex":
-            self.labels = [range(self.images.natoms)] * self.images.nimages
+            self.labels = [list(range(self.images.natoms))] * self.images.nimages
         elif an == "NoLabel":
             self.labels = None
         elif an == "MagMom":
@@ -371,7 +384,7 @@ class View:
         P = np.dot(self.X, self.axes)
         n = self.images.natoms
         P[:n] -= self.images.r[:, None]
-        P1 = P.min(0) 
+        P1 = P.min(0)
         P[:n] += 2 * self.images.r[:, None]
         P2 = P.max(0)
         self.center = np.dot(self.axes, (P1 + P2) / 2)
@@ -456,21 +469,31 @@ class View:
         elif self.colormode == 'force':
             F = self.images.F[self.frame]
             F = np.sqrt(((F*self.images.dynamic[:,np.newaxis])**2).sum(axis=-1))  # The absolute force
-            nF = (F - self.colormode_force_data[0]) * self.colormode_force_data[1]
+            nF = (F - self.colormode_data[0]) * self.colormode_data[1]
             nF = np.clip(nF.astype(int), 0, len(self.colors)-1)
             colors = np.array(colarray)[nF]
         elif self.colormode == 'velocity':
             V = self.images.V[self.frame]
             V = np.sqrt((V*V).sum(axis=-1))  # The absolute velocity
-            nV = (V - self.colormode_velocity_data[0]) * self.colormode_velocity_data[1]
+            nV = (V - self.colormode_data[0]) * self.colormode_data[1]
             nV = np.clip(nV.astype(int), 0, len(self.colors)-1)
             colors = np.array(colarray)[nV]
         elif self.colormode == 'charge':
             Q = self.images.q[self.frame]
-            nq = ((Q - self.colormode_charge_data[0]) * 
-                  self.colormode_charge_data[1]        )
+            nq = ((Q - self.colormode_data[0]) *
+                  self.colormode_data[1]        )
             nq = np.clip(nq.astype(int), 0, len(self.colors)-1)
             colors = np.array(colarray)[nq]
+        elif self.colormode == 'magnetic moment':
+            M = self.images.M[self.frame]
+            nm = ((M - self.colormode_data[0]) *
+                  self.colormode_data[1]        )
+            nm = np.clip(nm.astype(int), 0, len(self.colors)-1)
+            colors = np.array(colarray)[nm]
+        elif self.colormode == 'coordination':
+            if not hasattr(self, 'coordination'):
+                self.bind(self.frame)
+            colors = np.array(colarray)[self.coordination]
         elif self.colormode == 'manual':
             colors = colarray
         elif self.colormode == 'same':
@@ -512,9 +535,9 @@ class View:
                                       ])
                 # Ellipsoid rotated by quaternion as Matrix X' = R X R_transpose
                 El_r = np.dot(Q.rotation_matrix(),
-                              np.dot(Ellipsoid, 
+                              np.dot(Ellipsoid,
                                      np.transpose(Q.rotation_matrix())))
-                # Ellipsoid rotated by quaternion and axes as 
+                # Ellipsoid rotated by quaternion and axes as
                 # Matrix X' =  R_axes X' R_axes
                 El_v = np.dot(np.transpose(self.axes), np.dot(El_r, self.axes))
                 # Projection of rotated ellipsoid on xy plane
@@ -526,21 +549,21 @@ class View:
                         ])
                 # diagonal matrix der Ellipse gibt halbachsen
                 El_p_diag = np.linalg.eig(El_p)
-                # Winkel mit dem Ellipse in xy gedreht ist aus 
+                # Winkel mit dem Ellipse in xy gedreht ist aus
                 # eigenvektor der diagonal matrix
                 phi = atan(El_p_diag[1][0][1] / El_p_diag[1][0][0])
                 tupl = []
-                alpha = np.array(range(16)) * 2 * np.pi / 16
+                alpha = np.arange(16) * 2 * np.pi / 16
                 El_xy = np.array([sqrt(1. / (El_p_diag[0][0])) *
-                                  np.cos(alpha)*np.cos(phi) 
-                                  - sqrt(1./(El_p_diag[0][1])) * 
+                                  np.cos(alpha)*np.cos(phi)
+                                  - sqrt(1./(El_p_diag[0][1])) *
                                   np.sin(alpha) * np.sin(phi),
-                                  sqrt(1./(El_p_diag[0][0])) * 
+                                  sqrt(1./(El_p_diag[0][0])) *
                                   np.cos(alpha)*np.sin(phi)
-                                  + sqrt(1./(El_p_diag[0][1])) * 
+                                  + sqrt(1./(El_p_diag[0][1])) *
                                   np.sin(alpha) * np.cos(phi)])
 
-                tupl = (El_xy.transpose() * self.scale + 
+                tupl = (El_xy.transpose() * self.scale +
                         X[j][:2]).round().astype(int)
                 # XXX there must be a better way
                 tupl = [tuple(i) for i in tupl]
@@ -550,7 +573,7 @@ class View:
                 return self.pixmap.draw_arc(gc, fill, A[j, 0], A[j, 1], d[j],
                                             d[j], 0, 23040)
         else:
-            return self.pixmap.draw_arc(gc, fill, A[j, 0], A[j, 1], d[j], d[j], 
+            return self.pixmap.draw_arc(gc, fill, A[j, 0], A[j, 1], d[j], d[j],
                                         0, 23040)
 
     def arrow(self, begin, end):
@@ -618,7 +641,7 @@ class View:
                         # start labeling with atomic indexes
                         # to do: scale position and size with radius in some
                         # meaningful manner - pick a reference magnification
-                        # where it "looks good" and then go from there ... 
+                        # where it "looks good" and then go from there ...
                         nlabel = str(self.labels[self.frame][a])
                         colorl = self.foreground_gc
 
@@ -698,7 +721,7 @@ class View:
         color = self.foreground_gc
         line = self.pixmap.draw_line
         layout = self.drawing_area.create_pango_layout("Frame: " + n)
-        x = self.width - 3 - layout.get_size()[0] / pango.SCALE 
+        x = self.width - 3 - layout.get_size()[0] / pango.SCALE
         y = self.height - 5 - layout.get_size()[1] / pango.SCALE
         self.pixmap.draw_layout(self.foreground_gc, x, y, layout)
  
@@ -717,7 +740,7 @@ class View:
                 if a < self.images.natoms and hit[a]:
                     if event.state & gtk.gdk.CONTROL_MASK:
                         selected[a] = not selected[a]
-                        if selected[a]: 
+                        if selected[a]:
                             selected_ordered += [a]
                         elif len(selected_ordered) > 0:
                             if selected_ordered[-1] == a:
@@ -742,7 +765,7 @@ class View:
             if not (event.state & gtk.gdk.CONTROL_MASK):
                 selected[:] = False
             selected[indices] = True
-            if len(indices) == 1 and indices[0] not in self.images.selected_ordered: 
+            if len(indices) == 1 and indices[0] not in self.images.selected_ordered:
                 selected_ordered += [indices[0]]
             elif len(indices) > 1:
                 selected_ordered = []
@@ -798,7 +821,7 @@ class View:
                                  (-s * a, -s * b, c)])
             self.axes = np.dot(self.axes0, rotation)
             if self.images.natoms > 0:
-                com = self.X[:self.images.natoms].mean(0) 
+                com = self.X[:self.images.natoms].mean(0)
             else:
                 com = self.images.A[self.frame].mean(0)
             self.center = com - np.dot(com - self.center0,
@@ -845,7 +868,7 @@ class View:
     def external_viewer(self, action):
         name = action.get_name()
         command = {'Avogadro' : 'avogadro',
-                   'XMakeMol': 'xmakemol -f',
+                   'XMakeMol' : 'xmakemol -f',
                    'RasMol':'rasmol -xyz',
                    'VMD': 'vmd'}[name]
         fd, filename = tempfile.mkstemp('.xyz', 'ase.gui-')
