@@ -5,15 +5,17 @@ from zipfile import is_zipfile
 
 from ase.atoms import Atoms
 from ase.units import Bohr, Hartree
-from ase.io.trajectory import PickleTrajectory
+from ase.io.trajectory import Trajectory, PickleTrajectory
 from ase.io.bundletrajectory import BundleTrajectory
+from ase.io.netcdftrajectory import NetCDFTrajectory
 from ase.calculators.singlepoint import SinglePointDFTCalculator
 from ase.calculators.singlepoint import SinglePointKPoint
 
-__all__ = ['read', 'write', 'PickleTrajectory', 'BundleTrajectory']
+__all__ = ['read', 'write', 'Trajectory', 'PickleTrajectory',
+           'BundleTrajectory', 'NetCDFTrajectory']
 
 
-def read(filename, index=-1, format=None):
+def read(filename, index=None, format=None):
     """Read Atoms object(s) from file.
 
     filename: str
@@ -44,6 +46,8 @@ def read(filename, index=-1, format=None):
     XYZ-file                   xyz
     VASP POSCAR/CONTCAR file   vasp
     VASP OUTCAR file           vasp_out
+    VASP XDATCAR file          vasp_xdatcar
+    VASP vasprun.xml file      vasp_xml
     SIESTA STRUCT file         struct_out
     ABINIT input file          abinit
     V_Sim ascii file           v_sim
@@ -74,21 +78,37 @@ def read(filename, index=-1, format=None):
     Gaussian output file       gaussian_out
     Quantum espresso in file   esp_in
     Quantum espresso out file  esp_out
+    Extended XYZ file          extxyz
+    NWChem input file          nw
+    Materials Studio file      xsd
+    SHELX format               res    
     =========================  =============
 
+    Many formats allow on open file-like object to be passed instead
+    of ``filename``. In this case the format cannot be auto-decected,
+    so the ``format`` argument should be explicitly given.
+    
     """
-    if isinstance(filename, str):
-        p = filename.rfind('@')
-        if p != -1:
-            try:
-                index = string2index(filename[p + 1:])
-            except ValueError:
-                pass
-            else:
-                filename = filename[:p]
+    if isinstance(filename, str) and (
+        '.json@' in filename or
+        '.db@' in filename or
+        filename.startswith('pg://') and '@' in filename):
+        filename, index = filename.rsplit('@', 1)
+        if index.isdigit():
+            index = int(index)
+    else:
+        if isinstance(filename, str):
+            p = filename.rfind('@')
+            if p != -1:
+                try:
+                    index = string2index(filename[p + 1:])
+                except ValueError:
+                    pass
+                else:
+                    filename = filename[:p]
 
-    if isinstance(index, str):
-        index = string2index(index)
+        if isinstance(index, str):
+            index = string2index(index)
 
     if format is None:
         format = filetype(filename)
@@ -121,21 +141,34 @@ def read(filename, index=-1, format=None):
         else:
             magmoms = None
 
-        atoms.calc = SinglePointDFTCalculator(energy, forces, None, magmoms,
-                                              atoms)
+        atoms.calc = SinglePointDFTCalculator(atoms, energy=energy,
+                                              forces=forces, magmoms=magmoms)
         kpts = []
         if r.has_array('IBZKPoints'):
-            for w, kpt, eps_n, f_n in zip(r.get('IBZKPointWeights'), 
+            for w, kpt, eps_n, f_n in zip(r.get('IBZKPointWeights'),
                                           r.get('IBZKPoints'),
                                           r.get('Eigenvalues'),
                                           r.get('OccupationNumbers')):
-                print eps_n.shape, f_n.shape
                 kpts.append(SinglePointKPoint(w, kpt[0], kpt[1],
-                                              eps_n[0], f_n[0]  )) # XXX
+                                              eps_n[0], f_n[0]))
         atoms.calc.kpts = kpts
 
         return atoms
 
+    if format in ['json', 'db', 'postgresql']:
+        if index == slice(None, None):
+            index = None
+        from ase.db.core import connect
+        images = [row.toatoms()
+                  for row in connect(filename, format).select(index)]
+        if len(images) == 1:
+            return images[0]
+        else:
+            return images
+
+    if index is None:
+        index = -1
+        
     if format == 'castep':
         from ase.io.castep import read_castep
         return read_castep(filename, index)
@@ -152,14 +185,18 @@ def read(filename, index=-1, format=None):
         from ase.io.exciting import read_exciting
         return read_exciting(filename, index)
 
-    if format == 'xyz':
-        from ase.io.xyz import read_xyz
+    if format in ['xyz', 'extxyz']:
+        from ase.io.extxyz import read_xyz
         return read_xyz(filename, index)
 
     if format == 'traj':
         from ase.io.trajectory import read_trajectory
         return read_trajectory(filename, index)
 
+    if format == 'trj':
+        from ase.io.pickletrajectory import read_trajectory
+        return read_trajectory(filename, index)
+
     if format == 'bundle':
         from ase.io.bundletrajectory import read_bundletrajectory
         return read_bundletrajectory(filename, index)
@@ -196,6 +233,14 @@ def read(filename, index=-1, format=None):
         from ase.io.vasp import read_vasp_out
         return read_vasp_out(filename, index)
 
+    if format == 'vasp_xdatcar':
+        from ase.io.vasp import read_vasp_xdatcar
+        return read_vasp_xdatcar(filename, index)
+
+    if format == 'vasp_xml':
+        from ase.io.vasp import read_vasp_xml
+        return read_vasp_xml(filename, index)
+
     if format == 'abinit':
         from ase.io.abinit import read_abinit
         return read_abinit(filename)
@@ -280,12 +325,12 @@ def read(filename, index=-1, format=None):
         from ase.io.gen import read_gen
         return read_gen(filename)
 
-    if format == 'db':
+    if format == 'cmr':
         from ase.io.cmr_io import read_db
         return read_db(filename, index)
 
     if format == 'lammps':
-        from ase.io.lammps import read_lammps_dump
+        from ase.io.lammpsrun import read_lammps_dump
         return read_lammps_dump(filename, index)
 
     if format == 'eon':
@@ -312,7 +357,19 @@ def read(filename, index=-1, format=None):
         from ase.io.espresso import read_espresso_out
         return read_espresso_out(filename, index)
 
-    raise RuntimeError('File format descriptor '+format+' not recognized!')
+    if format == 'nw':
+        from ase.io.nwchem import read_nwchem_input
+        return read_nwchem_input(filename)
+
+    if format == 'xsd':
+        from ase.io.xsd import read_xsd
+        return read_xsd(filename)
+
+    if format in ['shelx', 'res']:
+        from ase.io.res import read_res
+        return read_res(filename, index)
+
+    raise RuntimeError('File format descriptor ' + format + ' not recognized!')
 
 
 def write(filename, images, format=None, **kwargs):
@@ -362,9 +419,16 @@ def write(filename, images, format=None, **kwargs):
     EON reactant.con file      eon
     Gromacs coordinates        gro
     GROMOS96 (only positions)  g96
-
+    X3D                        x3d
+    X3DOM HTML                 html
+    Extended XYZ file          extxyz
+    SHELX format               res
     =========================  ===========
 
+    Many formats allow on open file-like object to be passed instead
+    of ``filename``. In this case the format cannot be auto-decected,
+    so the ``format`` argument should be explicitly given.
+
     The use of additional keywords is format specific.
 
     The ``cube`` and ``plt`` formats accept (plt requires it) a ``data``
@@ -412,6 +476,11 @@ def write(filename, images, format=None, **kwargs):
     ``image_plane``, ``camera_type``, ``point_lights``,
     ``area_light``, ``background``, ``textures``, ``celllinewidth``,
     ``bondlinewidth``, ``bondatoms``
+
+    The ``xyz`` format accepts a comment string using the ``comment`` keyword:
+
+    comment: str (default '')
+      Optional comment written on the second line of the file.
     """
 
     if format is None:
@@ -422,6 +491,8 @@ def write(filename, images, format=None, **kwargs):
             format = 'vasp'
         elif 'OUTCAR' in filename:
             format = 'vasp_out'
+        elif 'vasp' in filename and filename.endswith('.xml'):
+            format = 'vasp_xml'
         elif filename.endswith('etsf.nc'):
             format = 'etsf'
         elif filename.lower().endswith('.con'):
@@ -430,8 +501,8 @@ def write(filename, images, format=None, **kwargs):
             format = 'tmol'
         else:
             suffix = filename.split('.')[-1]
-            format = {'cell':'castep_cell',
-                    }.get(suffix, suffix) # XXX this does not make sense
+            format = {'cell': 'castep_cell',
+                      }.get(suffix, suffix)  # XXX this does not make sense
             # Maybe like this:
 ##             format = {'traj': 'trajectory',
 ##                       'nc': 'netcdf',
@@ -439,7 +510,11 @@ def write(filename, images, format=None, **kwargs):
 ##                       'in': 'aims',
 ##                       'tmol': 'turbomole',
 ##                       }.get(suffix, suffix)
-
+            
+    if format in ['json', 'db']:
+        from ase.db import connect
+        connect(filename, format).write(images)
+        return
     if format == 'castep_cell':
         from ase.io.castep import write_cell
         write_cell(filename, images, **kwargs)
@@ -452,8 +527,13 @@ def write(filename, images, format=None, **kwargs):
         from ase.io.cif import write_cif
         write_cif(filename, images)
     if format == 'xyz':
-        from ase.io.xyz import write_xyz
-        write_xyz(filename, images)
+        from ase.io.extxyz import write_xyz
+        write_xyz(filename, images, columns=['symbols', 'positions'],
+                  write_info=False, write_results=False, **kwargs)
+        return
+    if format == 'extxyz':
+        from ase.io.extxyz import write_xyz
+        write_xyz(filename, images, **kwargs)
         return
     if format == 'gen':
         from ase.io.gen import write_gen
@@ -485,7 +565,7 @@ def write(filename, images, format=None, **kwargs):
         writer.write_atoms(images[0])
         writer.close()
         return
-    elif format == 'db' or format == 'cmr':
+    elif format == 'cmr':
         from ase.io.cmr_io import write_db
         return write_db(filename, images, **kwargs)
     elif format == 'eon':
@@ -500,6 +580,14 @@ def write(filename, images, format=None, **kwargs):
         from ase.io.gromos import write_gromos
         write_gromos(filename, images)
         return
+    elif format == 'html':
+        from ase.io.x3d import write_html
+        write_html(filename, images)
+        return
+    elif format in ['shelx', 'res']:
+        from ase.io.res import write_res
+        write_res(filename, images)
+        return    
 
     format = {'traj': 'trajectory',
               'nc': 'netcdf',
@@ -509,8 +597,10 @@ def write(filename, images, format=None, **kwargs):
 
     if format in ['vti', 'vts', 'vtu']:
         format = 'vtkxml'
-
-    if format is None:
+    elif format == 'trj':
+        name = 'write_trajectory'
+        format = 'pickletrajectory'
+    elif format is None:
         format = filetype(filename)
 
     try:
@@ -545,18 +635,30 @@ def filetype(filename):
         else:
             raise IOError('Directory: ' + filename)
 
-    fileobj = open(filename, 'rU')
+    if filename.startswith('pg://'):
+        return 'postgresql'
+
+    if filename.lower().endswith('.res'):
+        return 'res'    
+
+    fileobj = open(filename, 'rb')
     s3 = fileobj.read(3)
     if len(s3) == 0:
         raise IOError('Empty file: ' + filename)
 
-    if filename.lower().endswith('.db') or filename.lower().endswith('.cmr'):
+    if s3.startswith(b'{"'):
+        return 'json'
+
+    if filename.endswith('.db'):
         return 'db'
 
+    if filename.lower().endswith('.cmr'):
+        return 'cmr'
+
     if is_tarfile(filename):
         return 'gpw'
 
-    if s3 == 'CDF':
+    if s3 == b'CDF':
         from ase.io.pupynere import NetCDFFile
         nc = NetCDFFile(filename)
         if 'number_of_dynamic_atoms' in nc.dimensions:
@@ -573,31 +675,32 @@ def filetype(filename):
             return 'etsf'
         raise IOError('Unknown netCDF file!')
 
-
     if is_zipfile(filename):
         return 'vnl'
 
     fileobj.seek(0)
     lines = fileobj.readlines(1000)
-
-    if lines[0].startswith('PickleTrajectory'):
+    if lines[0].startswith(b'AFFormatASE-Trajectory'):
         return 'traj'
+    if lines[0].startswith(b'PickleTrajectory'):
+        return 'trj'
 
-    if lines[1].startswith('OUTER LOOP:') or filename.lower().endswith('.cube'):
+    if (lines[1].startswith(b'OUTER LOOP:') or
+        filename.lower().endswith('.cube')):
         return 'cube'
 
-    if '  ___ ___ ___ _ _ _  \n' in lines:
+    if b'  ___ ___ ___ _ _ _  \n' in lines:
         return 'gpaw-text'
 
-    if (' &&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&\n'
+    if (b' &&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&\n'
         in lines[:90]):
         return 'dacapo-text'
 
-
     for line in lines:
-        if line[0] != '#':
+        if line[0] != b'#':
             word = line.strip()
-            if word in ['ANIMSTEPS', 'CRYSTAL', 'SLAB', 'POLYMER', 'MOLECULE']:
+            if word in [b'ANIMSTEPS', b'CRYSTAL', b'SLAB', b'POLYMER',
+                        b'MOLECULE', b'ATOMS']:
                 return 'xsf'
 
     filename_v = os.path.basename(filename)
@@ -607,6 +710,12 @@ def filetype(filename):
     if 'OUTCAR' in filename_v:
         return 'vasp_out'
 
+    if 'XDATCAR' in filename_v:
+        return 'vasp_xdatcar'
+
+    if 'vasp' in filename_v and filename_v.endswith('.xml'):
+        return 'vasp_xml'
+
     if filename.lower().endswith('.exi'):
         return 'exi'
 
@@ -630,12 +739,15 @@ def filetype(filename):
         line = fileobj.readline()
         if not line:
             break
-        if 'Invoking FHI-aims ...' in line:
+        if b'Invoking FHI-aims ...' in line:
             return 'aims_out'
-        if 'atom' in line:
+        if b'atom' in line:
             data = line.split()
             try:
-                a = Atoms(symbols=[data[4]],positions = [[float(data[1]),float(data[2]),float(data[3])]])
+                Atoms(symbols=[data[4]],
+                      positions=[[float(data[1]),
+                                  float(data[2]),
+                                  float(data[3])]])
                 return 'aims'
             except:
                 pass
@@ -659,13 +771,14 @@ def filetype(filename):
     if filename.endswith('I_info'):
         return 'Cmdft'
 
-    if lines[0].startswith('$coord') or os.path.basename(filename) == 'coord':
+    if lines[0].startswith(b'$coord') or os.path.basename(filename) == 'coord':
         return 'tmol'
 
-    if lines[0].startswith('$grad') or os.path.basename(filename) == 'gradient':
+    if (lines[0].startswith(b'$grad') or
+        os.path.basename(filename) == 'gradient'):
         return 'tmol-gradient'
 
-    if lines[0].startswith('Geometry'):
+    if lines[0].startswith(b'Geometry'):
         return 'dftb'
 
     if filename.lower().endswith('.geom'):
@@ -676,7 +789,7 @@ def filetype(filename):
 
     if filename.lower().endswith('.cell'):
         return 'castep_cell'
-    if s3 == '<?x':
+    if s3 == b'<?x' and not filename.endswith('xsd'):
         from ase.io.vtkxml import probe_vtkxml
         xmltype = probe_vtkxml(filename)
         if xmltype == 'ImageData':
@@ -697,7 +810,7 @@ def filetype(filename):
     if filename.lower().endswith('.con'):
         return 'eon'
 
-    if 'ITEM: TIMESTEP\n' in lines:
+    if b'ITEM: TIMESTEP\n' in lines:
         return 'lammps'
 
     if filename.lower().endswith('.gro'):
@@ -715,4 +828,13 @@ def filetype(filename):
     if filename.lower().endswith('.out'):
         return 'esp_out'
 
+    if filename.endswith('.nw'):
+        return 'nw'
+
+    if filename.endswith('xsd'):
+        return 'xsd'
+
+    if filename.lower().endswith('.extxyz'):
+        return 'extxyz'
+
     return 'xyz'
