@@ -1,3 +1,4 @@
+from __future__ import print_function
 """bundletrajectory - a module for I/O from large MD simulations.
 
 The BundleTrajectory class writes trajectory into a directory with the
@@ -17,14 +18,15 @@ following structure::
         F1 (dir)
 """
 
-import ase.parallel 
+import ase.parallel
 from ase.parallel import paropen
 from ase.calculators.singlepoint import SinglePointCalculator
 import numpy as np
 import os
 import shutil
 import time
-import cPickle as pickle
+import pickle
+import collections
 
 class BundleTrajectory:
     """Reads and writes atoms into a .bundle directory.
@@ -196,7 +198,7 @@ class BundleTrajectory:
             except (RuntimeError, NotImplementedError):
                 self.datatypes['forces'] = False
             else:
-                self.backend.write(framedir, 'forces', x) 
+                self.backend.write(framedir, 'forces', x)
                 del x
         if datatypes.get('energies'):
             try:
@@ -204,7 +206,7 @@ class BundleTrajectory:
             except (RuntimeError, NotImplementedError):
                 self.datatypes['energies'] = False
             else:
-                self.backend.write(framedir, 'energies', x) 
+                self.backend.write(framedir, 'energies', x)
                 del x
         # Write any extra data
         for (label, source, once) in self.extra_data:
@@ -212,7 +214,7 @@ class BundleTrajectory:
                 if source is not None:
                     x = source()
                 else:
-                    x = atoms.arrays[label]
+                    x = atoms.get_array(label)
                 self.backend.write(framedir, label, x)
                 del x
                 if once:
@@ -271,6 +273,7 @@ class BundleTrajectory:
         "Closes the trajectory."
         self.state = 'closed'
         lf = getattr(self, 'logfile', None)
+        self.backend.close(log=lf)
         if lf is not None:
             lf.close()
             del self.logfile
@@ -323,16 +326,16 @@ class BundleTrajectory:
         data['constraint'] = smalldata['constraints']
         if self.subtype == 'split':
             self.backend.set_fragments(smalldata['fragments'])
-            atom_id = self.backend.read_split(framedir, 'ID')
+            self.atom_id, dummy = self.backend.read_split(framedir, 'ID')
         else:
-            atom_id = None
+            self.atom_id = None
         atoms = ase.Atoms(**data)
         natoms = smalldata['natoms']
         for name in ('positions', 'numbers', 'tags', 'masses',
                      'momenta'):
             if self.datatypes.get(name):
                 atoms.arrays[name] = self._read_data(framezero, framedir,
-                                                     name, atom_id)
+                                                     name, self.atom_id)
                 assert len(atoms.arrays[name]) == natoms
                 
         # Create the atoms object
@@ -368,7 +371,8 @@ class BundleTrajectory:
             raise IndexError('Trajectory index %d out of range [0, %d['
                              % (n, self.nframes))
         framedir = os.path.join(self.filename, 'F' + str(n))
-        return self.backend.read(framedir, name) 
+        framezero = os.path.join(self.filename, 'F0')
+        return self._read_data(framezero, framedir, name, self.atom_id)
 
     def _read_data(self, f0, f, name, atom_id):
         "Read single data item."
@@ -380,10 +384,11 @@ class BundleTrajectory:
                 d = self.backend.read(f, name)
         elif self.subtype == 'split':
             if self.datatypes[name] == 'once':
-                d = self.backend.read_split(f0, name)
+                d, issplit = self.backend.read_split(f0, name)
             else:
-                d = self.backend.read_split(f, name)
-            if atom_id is not None:
+                d, issplit = self.backend.read_split(f, name)
+            if issplit:
+                assert atom_id is not None
                 assert len(d) == len(atom_id)
                 d = d[atom_id]
         return d
@@ -397,9 +402,9 @@ class BundleTrajectory:
         if self.master:
             lfn = os.path.join(self.filename, "log.txt")
         else:
-            lfn = os.path.join(self.filename, ("log-node%d.txt" % 
+            lfn = os.path.join(self.filename, ("log-node%d.txt" %
                                                (ase.parallel.rank,)))
-        self.logfile = open(lfn, "a")   # Append to log if it exists.
+        self.logfile = open(lfn, "a", 1)   # Append to log if it exists.
         if hasattr(self, 'logdata'):
             for text in self.logdata:
                 self.logfile.write(text + '\n')
@@ -413,12 +418,12 @@ class BundleTrajectory:
         if os.path.exists(self.filename):
             # The output directory already exists.
             if not self.is_bundle(self.filename):
-                raise IOError("Filename '" + self.filename + 
-                              "' already exists, but is not a BundleTrajectory." + 
+                raise IOError("Filename '" + self.filename +
+                              "' already exists, but is not a BundleTrajectory." +
                               "Cowardly refusing to remove it.")
             ase.parallel.barrier() # All must have time to see it exists.
             if self.is_empty_bundle(self.filename):
-                self.log('Deleting old "%s" as it is empty' % (self.filename,)) 
+                self.log('Deleting old "%s" as it is empty' % (self.filename,))
                 self.delete_bundle(self.filename)
             elif not backup:
                 self.log('Deleting old "%s" as backup is turned off.' % (self.filename,))
@@ -467,6 +472,33 @@ class BundleTrajectory:
         self.datatypes = metadata['datatypes']
         self.state = 'read'
         
+    def _open_append(self, atoms):
+        if not os.path.exists(self.filename):
+            # OK, no old bundle.  Open as for write instead.
+            ase.parallel.barrier()
+            self._open_write(atoms, False)
+            return
+        if not self.is_bundle(self.filename):
+            raise IOError('Not a BundleTrajectory: ' + self.filename)
+        self.state = 'read'
+        metadata = self._read_metadata()
+        self.metadata = metadata
+        if metadata['version'] != self.version:
+            raise NotImplementedError(
+                "Cannot append to a BundleTrajectory version %s (supported version is %s)"
+                % (str(metadata['version']), str(self.version)))
+        if metadata['subtype'] not in ('normal', 'split'):
+            raise NotImplementedError(
+                "This version of ASE cannot append to BundleTrajectory subtype "
+                + metadata['subtype'])
+        self.subtype = metadata['subtype']
+        self._set_backend(metadata['backend'])
+        self.nframes = self._read_nframes()
+        self._open_log()
+        self.log('Opening "%s" in append mode (nframes=%i)' % (self.filename, self.nframes))
+        self.state = 'write'
+        self.atoms = atoms
+        
     def _write_nframes(self, n):
         "Write the number of frames in the bundle."
         assert self.state == 'write' or self.state == 'prewrite'
@@ -589,6 +621,7 @@ class BundleTrajectory:
         """
         framedir = os.path.join(self.filename, "F" + str(frame))
         if self.master:
+            self.log("Making directory " + framedir)
             os.mkdir(framedir)
         return framedir
 
@@ -601,7 +634,7 @@ class BundleTrajectory:
 
         All other arguments are stored, and passed to the function.
         """
-        if not callable(function):
+        if not isinstance(function, collections.Callable):
             raise ValueError("Callback object must be callable.")
         self.pre_observers.append((function, interval, args, kwargs))
 
@@ -614,7 +647,7 @@ class BundleTrajectory:
 
         All other arguments are stored, and passed to the function.
         """
-        if not callable(function):
+        if not isinstance(function, collections.Callable):
             raise ValueError("Callback object must be callable.")
         self.post_observers.append((function, interval, args, kwargs))
 
@@ -694,8 +727,17 @@ class PickleBundleBackend:
         self.nfrag = nfrag
         
     def read_split(self, framedir, name):
-        "Read data from multiple files."
+        """Read data from multiple files.
+        
+        Falls back to reading from single file if that is how data is stored.
+
+        Returns the data and a flag indicating if the data was really read from
+        split files.
+        """
         data = []
+        if os.path.exists(os.path.join(framedir, name + '.pickle')):
+            # Not stored in split form!
+            return (self.read(framedir, name), False)
         for i in range(self.nfrag):
             suf = "_%d" % (i,)
             fn = os.path.join(framedir, name + suf + '.pickle')
@@ -703,7 +745,14 @@ class PickleBundleBackend:
             shape = pickle.load(f)  # Discarded.
             data.append(pickle.load(f))
             f.close()
-        return np.concatenate(data)
+        return (np.concatenate(data), True)
+    
+    def close(self, log=None):
+        """Close anything that needs to be closed by the backend.
+        
+        The default backend does nothing here.
+        """
+        pass
     
 def read_bundletrajectory(filename, index=-1):
     """Reads one or more atoms objects from a BundleTrajectory.
@@ -772,33 +821,34 @@ def write_bundletrajectory(filename, images):
         traj.write(atoms)
     traj.close()
 
+    
 def print_bundletrajectory_info(filename):
     """Prints information about a BundleTrajectory.
 
     Mainly intended to be called from a command line tool.
     """
     if not BundleTrajectory.is_bundle(filename):
-        raise ValueError, "Not a BundleTrajectory!"
+        raise ValueError('Not a BundleTrajectory!')
     if BundleTrajectory.is_empty_bundle(filename):
-        print filename, "is an empty BundleTrajectory."
+        print(filename, 'is an empty BundleTrajectory.')
         return
     # Read the metadata
     f = open(os.path.join(filename, 'metadata'))
     metadata = pickle.load(f)
     f.close()
-    print "Metadata information of BundleTrajectory '%s':" % (filename,)
+    print("Metadata information of BundleTrajectory '%s':" % (filename,))
     for k, v in metadata.items():
         if k != 'datatypes':
-            print "  %s: %s" % (k, v)
+            print("  %s: %s" % (k, v))
     f = open(os.path.join(filename, 'frames'))
     nframes = int(f.read())
-    print "Number of frames: %i" % (nframes,)
-    print "Data types:"
+    print("Number of frames: %i" % (nframes,))
+    print("Data types:")
     for k, v in metadata['datatypes'].items():
         if v == 'once':
-            print "  %s: First frame only." % (k,)
+            print("  %s: First frame only." % (k,))
         elif v:
-            print "  %s: All frames." % (k,)
+            print("  %s: All frames." % (k,))
     # Look at first frame
     if metadata['backend'] == 'pickle':
         backend = PickleBundleBackend(True)
@@ -807,21 +857,21 @@ def print_bundletrajectory_info(filename):
                                   % (metadata['backend'],))
     frame = os.path.join(filename, "F0")
     small = backend.read_small(frame)
-    print "Contents of first frame:"
+    print("Contents of first frame:")
     for k, v in small.items():
         if k == 'constraints':
             if v:
-                print "  %i constraints are present"
+                print("  %i constraints are present")
             else:
-                print "  Constraints are absent."
+                print("  Constraints are absent.")
         elif k == 'pbc':
-            print "  Periodic boundary conditions: %s" % (str(v),)
+            print("  Periodic boundary conditions: %s" % (str(v),))
         elif k == 'natoms':
-            print "  Number of atoms: %i" % (v,)
+            print("  Number of atoms: %i" % (v,))
         elif hasattr(v, 'shape'):
-            print "  %s: shape = %s, type = %s" % (k, str(v.shape), str(v.dtype))
+            print("  %s: shape = %s, type = %s" % (k, str(v.shape), str(v.dtype)))
         else:
-            print "  %s: %s" % (k, str(v))
+            print("  %s: %s" % (k, str(v)))
     # Read info from separate files.
     for k, v in metadata['datatypes'].items():
         if v and not k in small:
@@ -831,7 +881,7 @@ def print_bundletrajectory_info(filename):
             else:
                 shape = info
                 dtype = 'unknown'
-            print "  %s: shape = %s, type = %s" % (k, str(shape), dtype)
+            print("  %s: shape = %s, type = %s" % (k, str(shape), dtype))
                 
             
             
