@@ -1,10 +1,11 @@
+from __future__ import division
 from math import sqrt
 
 from ase.atoms import Atoms, string2symbols
 from ase.data import reference_states, atomic_numbers, chemical_symbols
 
 
-def bulk(name, crystalstructure=None, a=None, c=None, covera=None,
+def bulk(name, crystalstructure=None, a=None, c=None, covera=None, u=None,
          orthorhombic=False, cubic=False):
     """Creating bulk systems.
 
@@ -15,13 +16,15 @@ def bulk(name, crystalstructure=None, a=None, c=None, covera=None,
         Chemical symbol or symbols as in 'MgO' or 'NaCl'.
     crystalstructure: str
         Must be one of sc, fcc, bcc, hcp, diamond, zincblende,
-        rocksalt, cesiumchloride, or fluorite.
+        rocksalt, cesiumchloride, fluorite or wurtzite.
     a: float
         Lattice constant.
     c: float
         Lattice constant.
     covera: float
-        c/a raitio used for hcp.  Use sqrt(8/3.0) for ideal ratio.
+        c/a raitio used for hcp.  Default is ideal ratio: sqrt(8/3).
+    u: float
+        Internal coordinate for Wurtzite structure.
     orthorhombic: bool
         Construct orthorhombic unit cell instead of primitive cell
         which is the default.
@@ -29,41 +32,37 @@ def bulk(name, crystalstructure=None, a=None, c=None, covera=None,
         Construct cubic unit cell if possible.
     """
 
-    if a is not None:
-        a = float(a)
-    if c is not None:
-        c = float(c)
-
     if covera is not None and c is not None:
         raise ValueError("Don't specify both c and c/a!")
 
+    xref = None
+    
     if name in chemical_symbols:
         Z = atomic_numbers[name]
         ref = reference_states[Z]
         if ref is not None:
             xref = ref['symmetry']
-        else:
-            xref = None
 
     if crystalstructure is None:
         crystalstructure = xref
 
     if a is None:
-        assert xref == crystalstructure
+        if xref != crystalstructure:
+            raise ValueError('You need to specify the lattice constant.')
         a = ref['a']
 
-    if crystalstructure == 'hcp':
+    if crystalstructure in ['hcp', 'wurtzite']:
         cubic = False
         if c is not None:
             covera = c / a
         elif covera is None:
-            if xref == 'hcp':
+            if xref == crystalstructure:
                 covera = ref['c/a']
             else:
-                covera = sqrt(8.0 / 3.0)
+                covera = sqrt(8 / 3)
 
     if orthorhombic and crystalstructure != 'sc':
-        return _orthorhombic_bulk(name, crystalstructure, a, covera)
+        return _orthorhombic_bulk(name, crystalstructure, a, covera, u)
 
     if cubic and crystalstructure in ['bcc', 'cesiumchloride']:
         return _orthorhombic_bulk(name, crystalstructure, a, covera)
@@ -83,7 +82,7 @@ def bulk(name, crystalstructure=None, a=None, c=None, covera=None,
     elif crystalstructure == 'hcp':
         atoms = Atoms(2 * name,
                       scaled_positions=[(0, 0, 0),
-                                        (1.0 / 3.0, 2.0 / 3.0, 0.5)],
+                                        (1 / 3, 2 / 3, 0.5)],
                       cell=[(a, 0, 0),
                             (-a / 2, a * sqrt(3) / 2, 0),
                             (0, 0, covera * a)],
@@ -106,14 +105,25 @@ def bulk(name, crystalstructure=None, a=None, c=None, covera=None,
         s1, s2, s3 = string2symbols(name)
         atoms = bulk(s1, 'fcc', a) + bulk(s2, 'fcc', a) + bulk(s3, 'fcc', a)
         atoms.positions[1, :] += a / 4
-        atoms.positions[2, :] += a * 3. / 4
+        atoms.positions[2, :] += a * 3 / 4
+    elif crystalstructure == 'wurtzite':
+        u = u or 0.25 + 1 / 3 / covera**2
+        atoms = Atoms(2 * name,
+                      scaled_positions=[(0, 0, 0),
+                                        (1 / 3, 2 / 3, 0.5 - u),
+                                        (1 / 3, 2 / 3, 0.5),
+                                        (0, 0, 1 - u)],
+                      cell=[(a, 0, 0),
+                            (-a / 2, a * sqrt(3) / 2, 0),
+                            (0, 0, a * covera)],
+                      pbc=True)
     else:
         raise ValueError('Unknown crystal structure: ' + crystalstructure)
 
     return atoms
 
 
-def _orthorhombic_bulk(name, crystalstructure, a, covera=None):
+def _orthorhombic_bulk(name, crystalstructure, a, covera=None, u=None):
     if crystalstructure == 'fcc':
         b = a / sqrt(2)
         atoms = Atoms(2 * name, cell=(b, b, a), pbc=True,
@@ -126,8 +136,8 @@ def _orthorhombic_bulk(name, crystalstructure, a, covera=None):
                       cell=(a, a * sqrt(3), covera * a),
                       scaled_positions=[(0, 0, 0),
                                         (0.5, 0.5, 0),
-                                        (0.5, 1.0 / 6.0, 0.5),
-                                        (0, 2.0 / 3.0, 0.5)],
+                                        (0.5, 1 / 6, 0.5),
+                                        (0, 2 / 3, 0.5)],
                       pbc=True)
     elif crystalstructure == 'diamond':
         atoms = _orthorhombic_bulk(2 * name, 'zincblende', a)
@@ -146,6 +156,19 @@ def _orthorhombic_bulk(name, crystalstructure, a, covera=None):
     elif crystalstructure == 'cesiumchloride':
         atoms = Atoms(name, cell=(a, a, a), pbc=True,
                       scaled_positions=[(0, 0, 0), (0.5, 0.5, 0.5)])
+    elif crystalstructure == 'wurtzite':
+        u = u or 0.25 + 1 / 3 / covera**2
+        atoms = Atoms(4 * name,
+                      cell=(a, a * 3**0.5, covera * a),
+                      scaled_positions = [(0, 0, 0),
+                                          (0, 1 / 3, 0.5 - u),
+                                          (0, 1 / 3, 0.5),
+                                          (0, 0, 1 - u),
+                                          (0.5, 0.5, 0),
+                                          (0.5, 5 / 6, 0.5 - u),
+                                          (0.5, 5 / 6, 0.5),
+                                          (0.5, 0.5, 1 - u)],
+                      pbc=True)
     else:
         raise RuntimeError
 
