@@ -19,13 +19,13 @@ class _Tetragonalize:
 
     def make_crystal_basis(self):
         lattice = self.latticeconstant
-        if type(lattice) == type({}):
+        if isinstance(lattice, type({})):
             lattice['b/a'] = 1.0
         else:
             if len(lattice) == 2:
                 lattice = (lattice[0], lattice[0], lattice[1])
             else:
-                raise ValueError, "Improper lattice constants for tetragonal crystal."
+                raise ValueError("Improper lattice constants for tetragonal crystal.")
         self.latticeconstant = lattice
         self.orthobase.make_crystal_basis(self)
 
