@@ -1,3 +1,4 @@
+from __future__ import print_function
 '''Constant pressure/stress and temperature dynamics.
 
 Combined Nose-Hoover and Parrinello-Rahman dynamics, creating an NPT
@@ -78,6 +79,8 @@ class NPT(MolecularDynamics):
         three Cartesian axes.  Set to (1,1,1) or None to allow
         a fully flexible computational box.  Set to (1,1,0)
         to disallow elongations along the z-axis etc.
+        mask may also be specified as a symmetric 3x3 array
+        indicating which strain values may change.
 
     Useful parameter values:
 
@@ -95,7 +98,7 @@ class NPT(MolecularDynamics):
     
     It has the following methods:
 
-    __call__(n)
+    run(n)
         Perform n timesteps.
     initialize()
         Estimates the dynamic variables for time=-1 to start
@@ -130,6 +133,7 @@ class NPT(MolecularDynamics):
     '''
 
     classname = "NPT"  # Used by the trajectory.
+    _npt_version = 2   # Version number, used for Asap compatibility.
     def __init__(self, atoms, 
                  timestep, temperature, externalstress, ttime, pfactor,
                  mask=None, trajectory=None, logfile=None, loginterval=1):
@@ -161,15 +165,15 @@ class NPT(MolecularDynamics):
         Must be a symmetric 3x3 tensor, a 6-vector representing a symmetric
         3x3 tensor, or a number representing the pressure.
         """
-        if type(stress) == type(1.0) or type(stress) == type(1):
+        if isinstance(stress, type(1.0)) or isinstance(stress, type(1)):
             stress = array((-stress, -stress, -stress, 0.0, 0.0, 0.0))
         elif stress.shape == (3,3):
             if not self._issymmetric(stress):
-                raise ValueError, "The external stress must be a symmetric tensor."
+                raise ValueError("The external stress must be a symmetric tensor.")
             stress = array((stress[0,0], stress[1,1], stress[2,2], stress[1,2],
                             stress[0,2], stress[0,1]))
         elif stress.shape != (6,):
-            raise ValueError, "The external stress has the wrong shape."
+            raise ValueError("The external stress has the wrong shape.")
         self.externalstress = stress
 
     def set_mask(self, mask):
@@ -178,7 +182,7 @@ class NPT(MolecularDynamics):
         If set to None, all elements may change.  If set to a 3-vector
         of ones and zeros, elements which are zero specify directions
         along which the size of the computational box cannot change.
-        For example, if mask = {1,1,0} the length of the system along
+        For example, if mask = (1,1,0) the length of the system along
         the z-axis cannot change, although xz and yz shear is still
         possible.  To disable shear globally, set the mode to diagonal
         (not yet implemented).
@@ -188,7 +192,8 @@ class NPT(MolecularDynamics):
         if not hasattr(mask, "shape"):
             mask = array(mask)        
         if mask.shape != (3,) and mask.shape != (3,3):
-            raise "The mask has the wrong shape (must be a 3-vector or 3x3 matrix)"
+            raise RuntimeError('The mask has the wrong shape ' +
+                               '(must be a 3-vector or 3x3 matrix)')
         else:
             mask = not_equal(mask, 0)  # Make sure it is 0/1
 
@@ -212,7 +217,7 @@ class NPT(MolecularDynamics):
     def set_strain_rate(self, rate):
         "Set the strain rate.  Must be an upper triangular 3x3 matrix."
         if not (rate.shape == (3,3) and self._isuppertriangular(rate)):
-            raise ValueError, "Strain rate must be an upper triangular matrix."
+            raise ValueError("Strain rate must be an upper triangular matrix.")
         self.eta = rate
         if self.initialized:
             # Recalculate h_past and eta_past so they match the current value.
@@ -228,9 +233,9 @@ class NPT(MolecularDynamics):
             self.initialize()
         else:
             if self.have_the_atoms_been_changed():
-                raise NotImplementedError, "You have modified the atoms since the last timestep."
+                raise NotImplementedError("You have modified the atoms since the last timestep.")
 
-        for i in xrange(steps):
+        for i in range(steps):
             self.step()
             self.nsteps += 1
             self.call_observers()
@@ -290,10 +295,8 @@ class NPT(MolecularDynamics):
         self.h_past = self.h
         self.h = h_future
         self.inv_h = linalg.inv(self.h)
-        # Do not throw away the q arrays, they are "magical" on parallel
-        # simulations (the contents migrate along with the atoms).
-        (self.q_past, self.q, self.q_future) = (self.q, self.q_future,
-                                                self.q_past)
+        self.q_past = self.q
+        self.q = self.q_future
         self._setbox_and_positions(self.h,self.q)
         self.eta_past = self.eta
         self.eta = eta_future
@@ -302,8 +305,6 @@ class NPT(MolecularDynamics):
         self._synchronize()  # for parallel simulations.
         self.zeta_integrated += dt * self.zeta
         force = self.forcecalculator()
-        # The periodic boundary conditions may have moved the atoms.
-        self.post_pbc_fix(fixfuture=0)  
         self._calculate_q_future(force)
         self.atoms.set_momenta(dot(self.q_future-self.q_past, self.h/(2*dt)) *
                                self._getmasses())
@@ -328,17 +329,16 @@ class NPT(MolecularDynamics):
         atoms = self.atoms
         self.h = self._getbox()
         if not self._isuppertriangular(self.h):
-            print "I am", self
-            print "self.h:"
-            print self.h
-            print "Min:", min((self.h[1,0], self.h[2,0], self.h[2,1]))
-            print "Max:", max((self.h[1,0], self.h[2,0], self.h[2,1]))
-            raise NotImplementedError, "Can (so far) only operate on lists of atoms where the computational box is an upper triangular matrix."
+            print("I am", self)
+            print("self.h:")
+            print(self.h)
+            print("Min:", min((self.h[1,0], self.h[2,0], self.h[2,1])))
+            print("Max:", max((self.h[1,0], self.h[2,0], self.h[2,1])))
+            raise NotImplementedError("Can (so far) only operate on lists of atoms where the computational box is an upper triangular matrix.")
         self.inv_h = linalg.inv(self.h)
         # The contents of the q arrays should migrate in parallel simulations.
-        self._make_special_q_arrays()
-        self.q[:] = dot(self.atoms.get_positions(),
-                                self.inv_h) - 0.5
+        #self._make_special_q_arrays()
+        self.q = dot(self.atoms.get_positions(), self.inv_h) - 0.5
         # zeta and eta were set in __init__
         self._initialize_eta_h()
         deltazeta = dt * self.tfact * (atoms.get_kinetic_energy() -
@@ -387,22 +387,6 @@ class NPT(MolecularDynamics):
             self._warning(self.classname+": Setting the center-of-mass momentum to zero (was %.6g %.6g %.6g)" % tuple(cm))
         self.atoms.set_momenta(self.atoms.get_momenta()
                                - cm / self._getnatoms())
-    
-    def post_pbc_fix(self, fixfuture=1):
-        """Correct for atoms moved by the boundary conditions.
-
-        If the fixfuture argument is 1 (the default), q_future is also
-        corrected.  This is not necessary when post_pbc_fix() is called from
-        within Timestep(), but must be done when the user calls post_pbc_fix
-        (for example if a CNA calculation may have triggered a migration).
-        """
-        q = dot(self.atoms.get_positions(),
-                           self.inv_h) - 0.5
-        delta_q = floor(0.5 + (q - self.q))
-        self.q += delta_q
-        self.q_past += delta_q
-        if fixfuture:
-            self.q_future += delta_q
         
     def attach_atoms(self, atoms):
         """Assign atoms to a restored dynamics object.
@@ -415,17 +399,16 @@ class NPT(MolecularDynamics):
         except AttributeError:
             pass
         else:
-            raise RuntimeError, "Cannot call attach_atoms on a dynamics which already has atoms."
+            raise RuntimeError("Cannot call attach_atoms on a dynamics which already has atoms.")
         MolecularDynamics.__init__(self, atoms, self.dt)
         ####self.atoms = atoms
         limit = 1e-6
         h = self._getbox()
         if max(abs((h - self.h).ravel())) > limit:
-            raise RuntimeError, "The unit cell of the atoms does not match the unit cell stored in the file."
+            raise RuntimeError("The unit cell of the atoms does not match the unit cell stored in the file.")
         self.inv_h = linalg.inv(self.h)
-        self._make_special_q_arrays()
-        self.q[:] = dot(self.atoms.get_positions(),
-                                           self.inv_h) - 0.5
+        #self._make_special_q_arrays()
+        self.q = dot(self.atoms.get_positions(), self.inv_h) - 0.5
         self._calculate_q_past_and_future()
         self.initialized = 1
         
@@ -566,8 +549,8 @@ class NPT(MolecularDynamics):
         beta = dt * dot(self.h, dot(self.eta + 0.5 * self.zeta * id3,
                                     self.inv_h))
         inv_b = linalg.inv(beta + id3)
-        self.q_future[:] = dot(2*self.q + dot(self.q_past, beta - id3) + alpha,
-                               inv_b)
+        self.q_future = dot(2*self.q + dot(self.q_past, beta - id3) + alpha,
+                            inv_b)
 
     def _calculate_q_past_and_future(self):
         def ekin(p, m = self.atoms.get_masses()):
@@ -579,7 +562,7 @@ class NPT(MolecularDynamics):
         p = array(p0, copy=1)
         dt = self.dt
         for i in range(2):
-            self.q_past[:] = self.q - dt * dot(p / m, self.inv_h)
+            self.q_past = self.q - dt * dot(p / m, self.inv_h)
             self._calculate_q_future(self.atoms.get_forces())
             p = dot(self.q_future - self.q_past, self.h/(2*dt)) * m
             e = ekin(p)
@@ -630,9 +613,9 @@ class NPT(MolecularDynamics):
 
     def _setbox_and_positions(self, h, q):
         """Set the computational box and the positions."""
-        self.atoms.set_cell(h, scale_atoms=True)
+        self.atoms.set_cell(h, scale_atoms=True)  # Why scale_atoms ...
         r = dot(q + 0.5, h)
-        self.atoms.set_positions(r)
+        self.atoms.set_positions(r)               # ... they are overwritten here ???
 
     # A few helper methods, which have been placed in separate methods
     # so they can be replaced in the parallel version.
