@@ -17,17 +17,20 @@ class LBFGS(Optimizer):
     """
     def __init__(self, atoms, restart=None, logfile='-', trajectory=None,
                  maxstep=None, memory=100, damping=1.0, alpha=70.0,
-                 use_line_search=False):
-        """
-        Parameters:
+                 use_line_search=False, master=None):
+        """Parameters:
+
+        atoms: Atoms object
+            The Atoms object to relax.
 
         restart: string
             Pickle file used to store vectors for updating the inverse of
             Hessian matrix. If set, file with such a name will be searched
             and information stored will be used, if the file exists.
 
-        logfile: string
-            Where should output go. None for no output, '-' for stdout.
+        logfile: file object or str
+            If *logfile* is a string, a file with that name will be opened.
+            Use '-' for stdout.
 
         trajectory: string
             Pickle file used to store trajectory of atomic movement.
@@ -50,9 +53,12 @@ class LBFGS(Optimizer):
             conservative value of 70.0 is the default, but number of needed
             steps to converge might be less if a lower value is used. However,
             a lower value also means risk of instability.
-            
+
+        master: boolean
+            Defaults to None, which causes only rank 0 to save files.  If
+            set to true,  this rank will save files.
         """
-        Optimizer.__init__(self, atoms, restart, logfile, trajectory)
+        Optimizer.__init__(self, atoms, restart, logfile, trajectory, master)
 
         if maxstep is not None:
             if maxstep > 1.0:
@@ -178,8 +184,8 @@ class LBFGS(Optimizer):
     def replay_trajectory(self, traj):
         """Initialize history from old trajectory."""
         if isinstance(traj, str):
-            from ase.io.trajectory import PickleTrajectory
-            traj = PickleTrajectory(traj, 'r')
+            from ase.io.trajectory import Trajectory
+            traj = Trajectory(traj, 'r')
         r0 = None
         f0 = None
         # The last element is not added, as we get that for free when taking
