@@ -1,11 +1,30 @@
+from __future__ import print_function
 import sys
 import time
 import atexit
+import pickle
 
 import numpy as np
 
+from ase.utils import devnull
 
-def paropen(name, mode='r', buffering=0):
+
+def get_txt(txt, rank):
+    if hasattr(txt, 'write'):
+        # Note: User-supplied object might write to files from many ranks.
+        return txt
+    elif rank == 0:
+        if txt is None:
+            return devnull
+        elif txt == '-':
+            return sys.stdout
+        else:
+            return open(txt, 'w', 1)
+    else:
+        return devnull
+
+
+def paropen(name, mode='r'):
     """MPI-safe version of open function.
 
     In read mode, the file is opened on all nodes.  In write and
@@ -14,37 +33,20 @@ def paropen(name, mode='r', buffering=0):
     """
     if rank > 0 and mode[0] != 'r':
         name = '/dev/null'
-    return open(name, mode, buffering)
+    return open(name, mode)
 
 
 def parprint(*args, **kwargs):
     """MPI-safe print - prints only from master.
-
-    Tries to adopt python 3 behaviour.
     """
-    if rank > 0:
-        return
-    defaults = {'end': '\n',
-                'file': sys.stdout }
-    for key in defaults:
-        if not key in kwargs:
-            kwargs[key] = defaults[key]
-
-    for arg in args[:-1]:
-        print >> kwargs['file'], arg,
-    if len(args):
-        last = args[-1]
-    else:
-        last = ''
-    if kwargs['end'] == '\n':
-        print >> kwargs['file'], last
-    else:
-        print >> kwargs['file'], last,
+    if rank == 0:
+        print(*args, **kwargs)
 
 
 class DummyMPI:
     rank = 0
     size = 1
+
     def sum(self, a):
         if isinstance(a, np.ndarray) and a.ndim > 0:
             pass
@@ -85,7 +87,6 @@ if '_gpaw' in sys.modules:
 elif 'asapparallel3' in sys.modules:
     # http://wiki.fysik.dtu.dk/Asap
     # We cannot import asap3.mpi here, as that creates an import deadlock
-    #from asap3.mpi import world
     import asapparallel3
     world = asapparallel3.Communicator()
 elif 'Scientific_mpi' in sys.modules:
@@ -101,6 +102,26 @@ size = world.size
 barrier = world.barrier
 
 
+def broadcast(obj, root=0, comm=world):
+    """Broadcast a Python object across an MPI communicator and return it."""
+    if comm.rank == root:
+        string = pickle.dumps(obj, pickle.HIGHEST_PROTOCOL)
+        n = np.array(len(string), int)
+    else:
+        string = None
+        n = np.empty(1, int)
+    comm.broadcast(n, root)
+    if comm.rank == root:
+        string = np.fromstring(string, np.int8)
+    else:
+        string = np.zeros(n, np.int8)
+    comm.broadcast(string, root)
+    if comm.rank == root:
+        return obj
+    else:
+        return pickle.loads(string.tostring())
+
+
 def register_parallel_cleanup_function():
     """Call MPI_Abort if python crashes.
 
@@ -123,23 +144,25 @@ def register_parallel_cleanup_function():
 
     atexit.register(cleanup)
 
-def distribute_cpus(parsize_calculator, comm):
+    
+def distribute_cpus(size, comm):
     """Distribute cpus to tasks and calculators.
 
-    parsize_calculator: number of nodes per calculator
-
+    Input:
+    size: number of nodes per calculator
     comm: total communicator object
+
+    Output:
+    communicator for this rank, number of calculators, index for this rank
     """
     
-    assert parsize_calculator <= comm.size
-    assert comm.size % parsize_calculator == 0
+    assert size <= comm.size
+    assert comm.size % size == 0
 
-    tasks_rank = comm.rank // parsize_calculator
+    tasks_rank = comm.rank // size
 
-    r0 = tasks_rank * parsize_calculator
-    ranks = np.arange(r0, r0 + parsize_calculator)
-    calc_comm = comm.new_communicator(ranks)
+    r0 = tasks_rank * size
+    ranks = np.arange(r0, r0 + size)
+    mycomm = comm.new_communicator(ranks)
 
-    tasks_comm = np.arange(0, comm.size, parsize_calculator)
-
-    return calc_comm, tasks_comm, tasks_rank
+    return mycomm, comm.size / size, tasks_rank
