@@ -1,11 +1,10 @@
 import os
+import warnings
+# cmr calls all available methods in ase.atoms detected by the module inspect.
+# Therefore also deprecated methods are called - and we choose to silence those warnings.
+#warnings.filterwarnings('ignore', 'ase.atoms.*deprecated',)
 
-from ase.test import NotAvailable
-
-try:
-    import cmr
-except ImportError:
-    raise NotAvailable('CMR is required')
+import cmr
 
 from ase.calculators.emt import EMT
 from ase.structure import molecule
