@@ -9,5 +9,5 @@ a1.translate((0, 0, 50))
 a3 = a1 + a2
 a3.calc = EMT()
 e3 = a3.get_potential_energy()
-print e1, e2, e3, e3 - e1 - e2
+print(e1, e2, e3, e3 - e1 - e2)
 assert abs(e3 - e1 - e2) < 1e-13
