@@ -12,17 +12,14 @@ atoms = Atoms('H7',
               constraint=[FixAtoms(range(6))],
               calculator=MorsePotential())
 
-traj = PickleTrajectory('H.traj', 'w', atoms)
+traj = Trajectory('H.traj', 'w', atoms)
 dyn = QuasiNewton(atoms, maxstep=0.2)
 dyn.attach(traj.write)
 dyn.run(fmax=0.01, steps=100)
 
-print atoms
+print(atoms)
 del atoms[-1]
-print atoms
+print(atoms)
 del atoms[5]
-print atoms
+print(atoms)
 assert len(atoms.constraints[0].index) == 5
-
-
-
