@@ -1,5 +1,5 @@
 from ase import Atoms
-from ase.io import PickleTrajectory
+from ase.io import Trajectory
 
 class Foo(object):
     def __init__(self, value):
@@ -9,7 +9,7 @@ class Foo(object):
 
 
 if __name__ == '__main__':
-    import info  # import ourselves to make info.Foo reachable
+    from . import info  # import ourselves to make info.Foo reachable
 
     # Create a molecule with an info attribute
     info = dict(creation_date='2011-06-27', 
@@ -26,12 +26,12 @@ if __name__ == '__main__':
     assert atoms.info == info
 
     # Save molecule to trajectory
-    traj = PickleTrajectory('info.traj', 'w', atoms=molecule)
+    traj = Trajectory('info.traj', 'w', atoms=molecule)
     traj.write()
     del traj
 
     # Load molecule from trajectory 
-    t = PickleTrajectory('info.traj')
+    t = Trajectory('info.traj')
     atoms = t[-1]
     assert atoms.info == info
 
