@@ -1,3 +1,4 @@
+from __future__ import print_function
 import sys
 
 import numpy as np
@@ -9,15 +10,15 @@ msg += "see: https://bugs.launchpad.net/ubuntu/+source/python-scientific/+bug/10
 import Scientific.IO.NetCDF as netcdf
 import Scientific
 version = Scientific.__version__.split(".")
-print 'Found ScientificPython version: ',Scientific.__version__
-if map(int,version) < [2,8]:
-    print 'ScientificPython 2.8 or greater required for numpy support in NetCDF'
+print('Found ScientificPython version: ',Scientific.__version__)
+if list(map(int,version)) < [2,8]:
+    print('ScientificPython 2.8 or greater required for numpy support in NetCDF')
     raise RuntimeError('ScientificPython version 2.8 or greater is requied')
 
 handle = netcdf.NetCDFFile("test.nc", "w")
 try:
     handle.test = np.array([1.0])
 except TypeError:
-    print >> sys.stderr, msg
+    print(msg, file=sys.stderr)
     raise
 handle.close()
