@@ -2,7 +2,7 @@ from math import sqrt
 from ase import Atoms
 from ase.constraints import StrainFilter
 from ase.optimize.mdmin import MDMin
-from ase.io import PickleTrajectory
+from ase.io import Trajectory
 try:
     from asap3 import EMT
 except ImportError:
@@ -15,7 +15,7 @@ else:
     cu.set_calculator(EMT())
     f = StrainFilter(cu, [1, 1, 1, 0, 0, 0])
     opt = MDMin(f, dt=0.01)
-    t = PickleTrajectory('Cu.traj', 'w', cu)
+    t = Trajectory('Cu.traj', 'w', cu)
     opt.attach(t)
     opt.run(0.001)
 
@@ -28,7 +28,7 @@ else:
     cu.set_calculator(EMT())
     f = StrainFilter(cu)
     opt = MDMin(f, dt=0.01)
-    t = PickleTrajectory('Cu.traj', 'w', cu)
+    t = Trajectory('Cu.traj', 'w', cu)
     opt.attach(t)
     opt.run(0.01)
 
