@@ -125,6 +125,7 @@ def plot_single(xdata, ydata, std,
          num=1,
          ):
     import matplotlib
+    matplotlib.rc('text', usetex=False)
     import pylab
     import matplotlib.font_manager
 
@@ -185,6 +186,7 @@ def plot(runs, data,
         stats['converged'].append(len([s for s in c if s is not None]))
     import matplotlib
     #matplotlib.use('Agg')
+    matplotlib.rc('text', usetex=False)
     from matplotlib import pylab, ticker
     num=1
     scale = [i for i in range(len(runs))]
@@ -388,7 +390,7 @@ class AnalyseOptimizersTask:
         for n, r in enumerate(runs):
             nd = [1 for k in datarun[r] if datarun[r][k]]
             if len(nd) == 0:
-                print 'skipped plotting empty data', r
+                print('skipped plotting empty data', r)
                 # no data for this run
                 i = plotruns.index(r)
                 plotruns.pop(i)
