@@ -16,14 +16,9 @@ From here::
 """
 
 import os
-
 import glob
-
 import pprint
-
 import urllib
-import urllib2
-
 import tarfile
 import zipfile
 
@@ -32,13 +27,20 @@ import numpy as np
 from numpy import array
 
 from ase import Atoms
-from ase import units
 import ase.io
 
 from ase.tasks.io import read_json
 from ase.tasks.bulk import BulkTask
 
 from ase.utils.eos import EquationOfState
+from ase.test import NotAvailable
+
+try:
+    import urllib2
+except ImportError:
+    raise NotAvailable
+
+
 
 class FullEquationOfState(EquationOfState):
 
@@ -66,7 +68,7 @@ class FullEquationOfState(EquationOfState):
         eV/Angstrom^3 - to get the value in GPa, do this::
 
           v0, e0, B0, B1, R = eos.fit()
-          print B0 / kJ * 1.0e24, 'GPa'
+          print(B0 / kJ * 1.0e24, 'GPa')
 
         """
 
@@ -103,80 +105,80 @@ class FullEquationOfState(EquationOfState):
 
 class DeltaCodesDFTCollection:
 
-    # http://molmod.ugent.be/sites/default/files/Delta_v2-0.zip
+    # https://molmod.ugent.be/sites/default/files/Delta_v3-0_0.zip
     wienref = """
     formula,V0,B0,B1
-    H,17.387,10.315,3.025
-    He,17.778,0.847,6.534
-    Li,20.216,13.879,3.754
-    Be,7.915,123.039,3.154
-    B,7.245,237.599,3.476
-    C,11.654,209.648,3.565
-    N,28.896,54.288,3.753
-    O,18.564,51.231,3.927
-    F,19.347,35.015,4.246
-    Ne,24.349,1.242,8.664
-    Na,37.089,7.728,3.736
-    Mg,22.934,35.748,4.263
-    Al,16.503,77.512,4.667
-    Si,20.553,88.673,4.227
-    P,21.614,68.863,4.416
-    S,17.346,85.495,4.440
-    Cl,39.175,19.324,4.489
-    Ar,52.209,0.704,7.838
-    K,73.710,3.586,3.734
-    Ca,42.208,17.300,3.167
-    Sc,24.621,54.559,3.402
-    Ti,17.407,112.712,3.591
-    V,13.517,185.231,3.731
-    Cr,11.910,183.841,7.374
-    Mn,11.611,131.159,0.852
-    Fe,11.451,196.127,6.137
-    Co,10.948,216.191,5.076
-    Ni,10.986,204.685,4.852
-    Cu,12.017,143.702,5.198
-    Zn,15.270,75.617,5.377
-    Ga,20.377,49.087,5.330
-    Ge,24.094,59.486,5.084
-    As,22.571,69.732,4.294
-    Se,29.973,47.637,4.548
-    Br,39.780,22.629,5.154
-    Kr,65.226,0.851,22.009
-    Rb,91.130,2.842,2.321
-    Sr,54.561,11.333,4.172
-    Y,32.864,41.320,2.952
-    Zr,23.402,94.061,3.247
-    Nb,18.155,168.691,3.504
-    Mo,15.825,260.410,4.264
-    Tc,14.472,301.391,4.555
-    Ru,13.810,315.359,4.955
-    Rh,14.082,260.576,5.440
-    Pd,15.326,170.442,5.854
-    Ag,17.855,91.328,5.799
-    Cd,22.866,44.247,7.089
-    In,27.497,34.759,4.870
-    Sn,36.883,36.020,5.038
-    Sb,31.786,50.718,4.495
-    Te,35.009,44.806,4.703
-    I,50.339,18.699,5.222
-    Xe,87.318,0.569,-0.724
-    Cs,117.748,1.964,3.592
-    Ba,63.200,8.431,3.299
-    Lu,29.060,47.725,4.048
-    Hf,22.551,108.082,3.225
-    Ta,18.296,193.730,4.774
-    W,16.175,302.590,4.300
-    Re,14.987,364.610,4.466
-    Os,14.320,402.199,4.352
-    Ir,14.533,341.743,6.958
-    Pt,15.678,251.750,5.342
-    Au,17.993,139.863,5.985
-    Hg,29.716,8.155,8.077
-    Tl,31.456,26.683,4.565
-    Pb,32.000,39.551,5.954
-    Bi,36.939,42.556,4.626
-    Po,37.570,45.523,5.018
-    Rn,92.765,0.544,13.133
+    H,17.3883,10.284,2.71
+    He,17.7708,0.847,7.71
+    Li,20.2191,13.839,3.34
+    Be,7.9099,122.903,3.04
+    B,7.2405,237.290,3.47
+    C,11.6366,208.991,3.58
+    N,28.8848,54.2195,3.7244
+    O,18.5590,51.378,3.89
+    F,19.1666,34.325,3.93
+    Ne,24.2492,1.406,14.44
+    Na,37.4686,7.472,3.77
+    Mg,22.9355,35.933,4.07
+    Al,16.4796,78.077,4.57
+    Si,20.4530,88.545,4.31
+    P,21.4709,68.208,4.35
+    S,17.1840,83.407,4.26
+    Cl,38.8889,19.081,4.34
+    Ar,52.3852,0.743,7.26
+    K,73.6793,3.574,4.59
+    Ca,42.1991,17.114,3.31
+    Sc,24.6196,54.393,3.42
+    Ti,17.3900,112.213,3.58
+    V,13.4520,181.674,3.75
+    Cr,11.7730,183.899,7.16
+    Mn,11.4473,118.632,-0.21
+    Fe,11.3436,197.652,5.80
+    Co,10.8599,217.295,4.37
+    Ni,10.8876,200.368,5.00
+    Cu,11.9511,141.335,4.86
+    Zn,15.1820,74.780,5.26
+    Ga,20.3069,49.223,5.38
+    Ge,23.9148,59.128,4.99
+    As,22.5890,68.285,4.22
+    Se,29.7437,47.070,4.44
+    Br,39.4470,22.415,4.87
+    Kr,65.6576,0.671,9.86
+    Rb,90.8087,2.787,5.80
+    Sr,54.5272,11.256,3.49
+    Y,32.8442,41.593,3.02
+    Zr,23.3850,93.684,3.21
+    Nb,18.1368,171.270,3.55
+    Mo,15.7862,258.928,4.33
+    Tc,14.4366,299.149,4.46
+    Ru,13.7619,312.502,4.95
+    Rh,14.0396,257.824,5.32
+    Pd,15.3101,168.629,5.56
+    Ag,17.8471,90.148,5.42
+    Cd,22.6287,46.403,6.92
+    In,27.4710,34.937,4.78
+    Sn,36.8166,36.030,4.64
+    Sb,31.7296,50.367,4.52
+    Te,34.9765,44.787,4.69
+    I,50.2333,18.654,5.05
+    Xe,86.6814,0.548,6.34
+    Cs,117.080,1.982,2.14
+    Ba,63.1401,8.677,3.77
+    Lu,29.0544,46.384,2.94
+    Hf,22.5325,107.004,3.50
+    Ta,18.2856,195.147,3.71
+    W,16.1394,301.622,4.28
+    Re,14.9580,362.850,4.52
+    Os,14.2802,397.259,4.84
+    Ir,14.5004,347.680,5.18
+    Pt,15.6420,248.711,5.46
+    Au,17.9745,139.109,5.76
+    Hg,29.5220,8.204,8.87
+    Tl,31.3902,26.865,5.49
+    Pb,32.0028,39.544,4.53
+    Bi,36.9047,42.630,4.70
+    Po,37.5869,45.458,4.93
+    Rn,92.6852,0.564,8.62
     """
 
     # http://molmod.ugent.be/sites/default/files/Delta_v1-1.zip
@@ -880,13 +882,13 @@ class DeltaCodesDFTTask(BulkTask):
 
 if __name__ == '__main__':
     # download and create the project databases
-    src = 'http://molmod.ugent.be/sites/default/files/Delta_v2-0.zip'
+    src = 'https://molmod.ugent.be/sites/default/files/Delta_v3-0.zip'
     name = os.path.basename(src)
     dir = 'Delta'
     if not os.path.exists(dir): os.makedirs(dir)
     os.chdir(dir)
     try:
-        resp = urllib2.urlopen(src)
+        resp = urllib.request.urlopen(src)
         urllib.urlretrieve(src, filename=name)
         z = zipfile.ZipFile(name)
         try:  # new in 2.6
