@@ -1,5 +1,3 @@
-#!/usr/bin/python
-
 """
 Run some VASP tests to ensure that the VASP calculator works. This
 is conditional on the existence of the VASP_COMMAND or VASP_SCRIPT
@@ -12,6 +10,7 @@ from ase.test.vasp import installed
 assert installed()
 
 from ase import Atoms
+from ase.io import write
 from ase.calculators.vasp import Vasp
 import numpy as np
 
@@ -36,6 +35,7 @@ calc = Vasp(
 
 co.set_calculator(calc)
 en = co.get_potential_energy()
+write('vasp_co.traj', co)
 assert abs(en + 14.918933) < 5e-3
 
 # Secondly, check that restart from the previously created VASP output works
