@@ -2,9 +2,8 @@ import numpy as np
 from ase import Atoms
 from ase.units import fs
 from ase.calculators.test import TestPotential
-from ase.calculators.emt import EMT
 from ase.md import VelocityVerlet
-from ase.io import PickleTrajectory, read
+from ase.io import Trajectory, read
 from ase.optimize import QuasiNewton
 
 np.seterr(all='raise')
@@ -15,9 +14,9 @@ a = Atoms('4X',
                      (0, 1, 0),
                      (0.1, 0.2, 0.7)],
           calculator=TestPotential())
-print a.get_forces()
+print(a.get_forces())
 md = VelocityVerlet(a, dt=0.5 * fs, logfile='-', loginterval=500)
-traj = PickleTrajectory('4N.traj', 'w', a)
+traj = Trajectory('4N.traj', 'w', a)
 md.attach(traj.write, 100)
 e0 = a.get_total_energy()
 md.run(steps=10000)
