@@ -44,7 +44,7 @@ class EquationOfStateSJEOS:
         eV/Angstrom^3 - to get the value in GPa, do this::
 
           v0, e0, B = eos.fit()
-          print B / kJ * 1.0e24, 'GPa'
+          print(B / kJ * 1.0e24, 'GPa')
 
         """
 
