@@ -3,25 +3,21 @@ import tempfile
 
 from ase.io import write
 import ase.parallel as parallel
-from ase.old import OldASEListOfAtomsWrapper
 
-def view(atoms, data=None, viewer='ag', repeat=None, block=False):
+
+def view(atoms, data=None, viewer='ase-gui', repeat=None, block=False):
     # Ignore for parallel calculations:
     if parallel.size != 1:
         return
 
-    if hasattr(atoms, 'GetUnitCell'):
-        # Convert old ASE ListOfAtoms to new style.
-        atoms = OldASEListOfAtomsWrapper(atoms).copy()
-
     vwr = viewer.lower()
     
-    if vwr == 'ag':
+    if vwr == 'ase-gui':
         format = 'traj'
         if repeat is None:
-            command = 'ag'
+            command = 'ase-gui'
         else:
-            command = 'ag --repeat=%d,%d,%d' % tuple(repeat)
+            command = 'ase-gui --repeat=%d,%d,%d' % tuple(repeat)
             repeat = None
     elif vwr == 'vmd':
         format = 'cube'
@@ -46,19 +42,17 @@ def view(atoms, data=None, viewer='ag', repeat=None, block=False):
         raise RuntimeError('Unknown viewer: ' + viewer)
 
     fd, filename = tempfile.mkstemp('.' + format, 'ase-')
-    fd = os.fdopen(fd, 'w')
     if repeat is not None:
         atoms = atoms.repeat()
     if data is None:
-        write(fd, atoms, format=format)
+        write(filename, atoms, format=format)
     else:
-        write(fd, atoms, format=format, data=data)
-    fd.close()
+        write(filename, atoms, format=format, data=data)
     if block:
         os.system('%s %s' % (command, filename))
         os.remove(filename)
     else:
-        if os.name in ['ce', 'nt']: # Win
+        if os.name in ['ce', 'nt']:  # Win
             # XXX: how to make it non-blocking?
             os.system('%s %s' % (command, filename))
             os.remove(filename)
