@@ -1,3 +1,4 @@
+from __future__ import print_function
 """An experimental package for making plots during a simulation.
 
 A PrimiPlotter can plot a list of atoms on one or more output devices.
@@ -7,6 +8,7 @@ from numpy import *
 from ase.visualize.colortable import color_table
 import ase.data
 import sys, os, time, weakref
+import collections
 
 class PrimiPlotterBase:
     "Base class for PrimiPlotter and Povrayplotter."
@@ -23,15 +25,22 @@ class PrimiPlotterBase:
         self.radius = radii
 
     def set_colors(self, colors):
-        """Explicitly set the colors of the atoms."""
+        """Explicitly set the colors of the atoms.
+        
+        The colors can either be a dictionary mapping tags to colors
+        or an array of colors, one per atom.
+        
+        Each color is specified as a greyscale value from 0.0 to 1.0
+        or as three RGB values from 0.0 to 1.0.
+        """
         self.colors = colors
 
     def set_color_function(self, colors):
         """Set a color function, to be used to color the atoms."""
-        if callable(colors):
+        if isinstance(colors, collections.Callable):
             self.colorfunction = colors
         else:
-            raise TypeError, "The color function is not callable."
+            raise TypeError("The color function is not callable.")
 
     def set_invisible(self, inv):
         """Choose invisible atoms."""
@@ -39,10 +48,10 @@ class PrimiPlotterBase:
 
     def set_invisibility_function(self, invfunc):
         """Set an invisibility function."""
-        if callable(invfunc):
+        if isinstance(invfunc, collections.Callable):
             self.invisibilityfunction = invfunc
         else:
-            raise TypeError, "The invisibility function is not callable."
+            raise TypeError("The invisibility function is not callable.")
 
     def set_cut(self, xmin=None, xmax=None, ymin=None, ymax=None,
                zmin=None, zmax=None):
@@ -94,8 +103,8 @@ class PrimiPlotterBase:
     def _stoptimer(self):
         elapsedtime = time.time() - self.starttime
         self.totaltime = self.totaltime + elapsedtime
-        print "plotting time %s sec (total %s sec)" % (elapsedtime,
-                                                       self.totaltime)
+        print("plotting time %s sec (total %s sec)" % (elapsedtime,
+                                                       self.totaltime))
 
     def _getpositions(self):
         return self.atoms.get_positions()
@@ -125,7 +134,7 @@ class PrimiPlotterBase:
     def _getcolors(self):
         # Try any explicitly given colors
         if self.colors is not None:
-            if type(self.colors) == type({}):
+            if isinstance(self.colors, type({})):
                 self.log("Explicit colors dictionary")
                 return _colorsfromdict(self.colors,
                                        asarray(self.atoms.get_tags(),int))
@@ -142,7 +151,7 @@ class PrimiPlotterBase:
         except AttributeError:
             c = None
         if c is not None:
-            if type(c) == type({}):
+            if isinstance(c, type({})):
                 self.log("Color dictionary from atoms.get_colors()")
                 return _colorsfromdict(c, asarray(self.atoms.get_tags(),int))
             else:
@@ -352,6 +361,7 @@ class PrimiPlotter(PrimiPlotterBase):
         self.ownlogfile = False
         
     def set_output(self, device):
+        "Attach an output device to the plotter."
         self.outputdevice.append(device)
         device.set_dimensions(self.dims)
         device.set_owner(weakref.proxy(self))
@@ -372,7 +382,7 @@ class PrimiPlotter(PrimiPlotterBase):
             radii = self._getradii()
             self._autoscale(coords, radii)
         else:
-            raise ValueError, "Unknown autoscale mode: ",+str(mode)
+            raise ValueError("Unknown autoscale mode: ").with_traceback(+str(mode))
 
     def set_scale(self, scale):
         self.autoscale("off")
@@ -441,7 +451,7 @@ class PrimiPlotter(PrimiPlotterBase):
         if typradius < 4.0:
             self.log("Refining visibility check.")
             if zoom >= 16:
-                raise RuntimeError, "Cannot check visibility - too deep recursion."
+                raise RuntimeError("Cannot check visibility - too deep recursion.")
             return self._computevisibility(xy*2, rad*2, invisible, id, zoom*2)
         else:
             self.log("Visibility(r_typ = %.1f pixels)" % (typradius,))
@@ -456,7 +466,7 @@ class PrimiPlotter(PrimiPlotterBase):
         # Atoms are visible if not hidden behind other atoms
         xy = floor(xy + 2*maxr + 0.5).astype(int)
         masks = {}
-        for i in xrange(len(rad)-1, -1, -1):
+        for i in range(len(rad)-1, -1, -1):
             if (i % 100000) == 0 and i:
                 self._verb(str(i))
             if not visible[i]:
@@ -520,13 +530,12 @@ class ParallelPrimiPlotter(PrimiPlotter):
     PrimiPlotter docstring for details.
     """
     def __init__(self, *args, **kwargs):
-        apply(PrimiPlotter.__init__, (self,)+args, kwargs)
+        PrimiPlotter.__init__(self, *args, **kwargs)
         self.isparallel = 1
-        import Scientific.MPI
-        self.MPI = Scientific.MPI
-        self.mpi = Scientific.MPI.world
+        import ase.parallel
+        self.mpi = ase.parallel.world
         if self.mpi is None:
-            raise RuntimeError, "MPI is not available."
+            raise RuntimeError("MPI is not available.")
         self.master = self.mpi.rank == 0
         self.mpitag = 42   # Reduce chance of collision with other modules.
         
@@ -540,14 +549,14 @@ class ParallelPrimiPlotter(PrimiPlotter):
 
     def _getpositions(self):
         realpos = self.atoms.get_positions()
-        ghostpos = self.atoms.GetGhostCartesianPositions()
+        ghostpos = self.atoms.get_ghost_positions()
         self.numberofrealatoms = len(realpos)
         self.numberofghostatoms = len(ghostpos)
         return concatenate((realpos, ghostpos))
 
     def _getatomicnumbers(self):
         realz = self.atoms.get_atomic_numbers()
-        ghostz = self.atoms.GetGhostAtomicNumbers()
+        ghostz = self.atoms.get_ghost_atomic_numbers()
         return concatenate((realz, ghostz))
 
     def _getradius(self):
@@ -565,12 +574,10 @@ class ParallelPrimiPlotter(PrimiPlotter):
         # max(x) and min(x) only works for rank-1 arrays in Numeric version 17.
         maximal = maximum.reduce(coords[:,0:2])
         minimal = minimum.reduce(coords[:,0:2])
-        recvmax = zeros(2, maximal.typecode())
-        recvmin = zeros(2, minimal.typecode())
-        self.mpi.allreduce(maximal, recvmax, self.MPI.max)
-        self.mpi.allreduce(minimal, recvmin, self.MPI.min)
-        maxx, maxy = recvmax
-        minx, miny = recvmin
+        self.mpi.max(maximal)
+        self.mpi.min(minimal)
+        maxx, maxy = maximal
+        minx, miny = minimal
         return array([maxx + minx, maxy + miny, 0.0]) / 2.0
 
     def _computevisibility(self, xy, rad, invisible, id, zoom = 1):
@@ -587,12 +594,10 @@ class ParallelPrimiPlotter(PrimiPlotter):
         assert len(x) == len(self.atoms)
         maximal = array([max(x), max(y), max(radii[:n])])
         minimal = array([min(x), min(y)])
-        recvmax = zeros(3, maximal.typecode())
-        recvmin = zeros(2, minimal.typecode())
-        self.mpi.allreduce(maximal, recvmax, self.MPI.max)
-        self.mpi.allreduce(minimal, recvmin, self.MPI.min)
-        maxx, maxy, maxradius = recvmax
-        minx, miny = recvmin
+        self.mpi.max(maximal)
+        self.mpi.min(minimal)
+        maxx, maxy, maxradius = maximal
+        minx, miny = minimal
         deltax = maxx - minx + 2*maxradius
         deltay = maxy - miny + 2*maxradius
         scalex = self.dims[0] / deltax
@@ -602,9 +607,9 @@ class ParallelPrimiPlotter(PrimiPlotter):
 
     def _getcolors(self):
         col = PrimiPlotter._getcolors(self)
-        nghost = len(self.atoms.GetGhostCartesianPositions())
+        nghost = len(self.atoms.get_ghost_positions())
         newcolshape = (nghost + col.shape[0],) + col.shape[1:]
-        newcol = zeros(newcolshape, col.typecode())
+        newcol = zeros(newcolshape, col.dtype)
         newcol[:len(col)] = col
         return newcol
     
@@ -616,35 +621,35 @@ class ParallelPrimiPlotter(PrimiPlotter):
             ncol = colors.shape[1]  # 1 or 3.
             assert ncol == 3  # RGB values
         # If one processor says RGB, all must convert
-        ncolthis = array([ncol])
-        ncolmax = zeros((1,), ncolthis.typecode())
-        self.mpi.allreduce(ncolthis, ncolmax, self.MPI.max)
-        ncolmax = ncolmax[0]
+        ncolmax = self.mpi.max(ncol)
         if ncolmax > ncol:
             assert ncol == 1
             colors = colors[:,newaxis] + zeros(ncolmax)[newaxis,:]
             ncol = ncolmax
             assert colors.shape == (len(coords), ncol)
         # Now send data from slaves to master
-        data = zeros((len(coords)+1, 4+ncol), float)
-        data[:-1,:3] = coords
-        data[:-1,3] = radii
-        data[-1,-1] = 4+ncol  # Used to communicate shape
+        data = zeros((len(coords), 4+ncol), float)
+        data[:,:3] = coords
+        data[:,3] = radii
         if ncol == 1:
-            data[:-1,4] = colors
+            data[:,4] = colors
         else:
-            data[:-1,4:] = colors
+            data[:,4:] = colors
         if not self.master:
+            datashape = array(data.shape)
+            assert datashape.shape == (2,)
+            self.mpi.send(datashape, 0, self.mpitag)
             self.mpi.send(data, 0, self.mpitag)
         else:
-            total = [data[:-1]]  # Last row is the dimensions.
+            total = [data]  
             n = len(coords)
             colsmin = colsmax = 4+ncol
             for proc in range(1, self.mpi.size):
                 self._verb("Receiving from processor "+str(proc))
-                fdat = self.mpi.receive(float, proc, self.mpitag)[0]
-                fdat.shape = (-1, fdat[-1])
-                fdat = fdat[:-1]  # Last row is the dimensions.
+                datashape = zeros(2, int)
+                self.mpi.receive(datashape, proc, self.mpitag)
+                fdat = zeros(tuple(datashape))
+                self.mpi.receive(fdat, proc, self.mpitag)
                 total.append(fdat)
                 n = n + len(fdat)
                 if fdat.shape[1] < colsmin:
@@ -804,7 +809,7 @@ class _PostScriptToFile(_PostScriptDevice):
     def __init__(self, prefix, compress = 0):
         self.compress = compress
         if "'" in prefix:
-            raise ValueError, "Filename may not contain a quote ('): "+prefix
+            raise ValueError("Filename may not contain a quote ('): "+prefix)
         if "%" in prefix:
             # Assume the user knows what (s)he is doing
             self.filenames = prefix
@@ -812,7 +817,7 @@ class _PostScriptToFile(_PostScriptDevice):
             self.filenames = prefix + "%04d" + self.suffix
             if compress:
                 if self.compr_suffix is None:
-                    raise RuntimeError, "Compression not supported."
+                    raise RuntimeError("Compression not supported.")
                 self.filenames = self.filenames + self.compr_suffix
         _PostScriptDevice.__init__(self)
 
@@ -829,7 +834,7 @@ class PostScriptFile(_PostScriptToFile):
             file = os.popen("gzip > '"+filename+"'", "w")
         else:
             file = open(filename, "w")
-        apply(plotmethod, (file, n)+args, kargs)
+        plotmethod(*(file, n)+args, **kargs)
         file.close()
 
 class _PS_via_PnmFile(_PostScriptToFile):
@@ -845,7 +850,7 @@ class _PS_via_PnmFile(_PostScriptToFile):
             
         cmd = (cmd+" > '%s'") % (self.dims[0], self.dims[1], filename)
         file = os.popen(cmd, "w")
-        apply(plotmethod, (file, n)+args, kargs)
+        plotmethod(*(file, n)+args, **kargs)
         file.close()
 
 class PnmFile(_PS_via_PnmFile):
@@ -875,7 +880,7 @@ class X11Window(_PostScriptDevice):
             file = os.popen(filename, "w")
             self.pipe = file
         kargs["noshowpage"] = 1
-        apply(plotmethod, (file, n)+args, kargs)
+        plotmethod(*(file, n)+args, **kargs)
         file.write("flushpage\n")
         file.flush()
 
@@ -893,13 +898,13 @@ def _rot(v, axis):
 
 def _colorsfromdict(dict, cls):
     """Extract colors from dictionary using cls as key."""
-    assert(type(dict) == type({}))
+    assert(isinstance(dict, type({})))
     # Allow local modifications, to replace strings with rgb values.
     dict = dict.copy()  
     isgray, isrgb = 0, 0
     for k in dict.keys():
         v = dict[k]
-        if type(v) == type("string"):
+        if isinstance(v, type("string")):
             v = color_table[v]
             dict[k] = v
         try:
@@ -908,7 +913,7 @@ def _colorsfromdict(dict, cls):
                 if not hasattr(v, "shape"):
                     dict[k] = array(v)   # Convert to array
             else:
-                raise RuntimeError, "Unrecognized color object "+repr(v)
+                raise RuntimeError("Unrecognized color object "+repr(v))
         except TypeError:
             isgray = 1 # Assume it is a number
     if isgray and isrgb:
@@ -922,7 +927,7 @@ def _colorsfromdict(dict, cls):
         colors = zeros((len(cls),3), float)
     else:
         colors = zeros((len(cls),), float)
-    for i in xrange(len(cls)):
+    for i in range(len(cls)):
         colors[i] = dict[cls[i]]
     return colors
 
