@@ -2,7 +2,7 @@
 # creates:  ener.png distance.png angle.png
 import os
 import matplotlib
-matplotlib.use('Agg')
+#matplotlib.use('Agg')
 import pylab as plt
 
 
