@@ -11,6 +11,6 @@ e_molecule = molecule.get_potential_energy()
 
 e_atomization = e_molecule - 2 * e_atom
 
-print 'Nitrogen atom energy: %5.2f eV' %e_atom
-print 'Nitrogen molecule energy: %5.2f eV' %e_molecule
-print 'Atomization energy: %5.2f eV' %-e_atomization
+print('Nitrogen atom energy: %5.2f eV' % e_atom)
+print('Nitrogen molecule energy: %5.2f eV' % e_molecule)
+print('Atomization energy: %5.2f eV' % -e_atomization)
