@@ -2,7 +2,7 @@
 import os
 from ase.io import read, write
 if 1:
-    execfile('diffusion4.py')
+    exec(compile(open('diffusion4.py').read(), 'diffusion4.py', 'exec'))
 images = [read('mep%d.traj' % i) for i in range(5)]
 a = images[0] + images[1] + images[2] + images[3] + images[4]
 del a.constraints
