@@ -1,11 +1,8 @@
-# creates:  hoppingsummary.png
-import matplotlib
-#matplotlib.use('Agg')
-from ase.optimize.minimahopping import MHPlot
+# creates:  summary.png
+
+exec(compile(open('Cu2_Pt110.py').read(), 'Cu2_Pt110.py', 'exec'))
+execfile('mhsummary.py')
 
-execfile('Cu2_Pt110.py')
-mhplot = MHPlot()
-mhplot.save_figure('hoppingsummary.png')
 # Clean up directory.
 import os
 os.remove('hop.log')
