@@ -3,7 +3,7 @@ from ase.constraints import FixAtoms
 from ase.calculators.emt import EMT
 from ase.neb import NEB
 from ase.optimize import BFGS
-from ase.io.trajectory import PickleTrajectory
+from ase.io.trajectory import Trajectory
 from ase.parallel import rank, size
 
 initial = read('initial.traj')
@@ -25,6 +25,6 @@ neb = NEB(images, parallel=True)
 neb.interpolate()
 qn = BFGS(neb)
 if rank % (size // 3) == 0:
-    traj = PickleTrajectory('neb%d.traj' % j, 'w', images[1 + j], master=True)
+    traj = Trajectory('neb%d.traj' % j, 'w', images[1 + j], master=True)
     qn.attach(traj)
 qn.run(fmax=0.05)
